@@ -21,7 +21,7 @@ import sys
 #
 # Entries are listed in alphabetical order.
 #
-docdict = {}
+docdict: dict[str, str] = {}
 
 ##############################################################################
 #
@@ -40,7 +40,7 @@ alphas : :obj:`float` or :obj:`list` of :obj:`float` or None, default=None
 # annotate
 docdict["annotate"] = """
 annotate : :obj:`bool`, default=True
-    If `annotate` is `True`, positions and left/right annotation
+    If `annotate` is `True` (like positions and / or  left/right annotation)
     are added to the plot.
 """
 
@@ -144,6 +144,13 @@ border_size : :obj:`int`, optional
     the image to determine the value of the background.
 """
 
+# brain_color
+docdict["brain_color"] = """
+brain_color : :obj:`tuple`, default=(0.5, 0.5, 0.5)
+    The brain color to use as the background color (e.g., for
+    transparent colorbars).
+"""
+
 # cbar_tick_format
 docdict["cbar_tick_format"] = """
 cbar_tick_format : :obj:`str`, optional
@@ -259,12 +266,22 @@ cmap : :class:`matplotlib.colors.Colormap`, or :obj:`str`, \
     passed as a pandas dataframe.
     If the look up table does not contain a ``color`` column,
     then the default colormap of this function will be used.
+
+    .. warning::
+
+        If the ``name`` column in the look up table
+        does not contain a ``background`` or ``Background`` value,
+        then the colormap will be shifted by one.
+
+        See `issue 5934 <https://github.com/nilearn/nilearn/issues/5934>`_.
+
+
 """
 
 # colorbar
 docdict["colorbar"] = """
 colorbar : :obj:`bool`, optional
-    If `True`, display a colorbar on the right of the plots.
+    If `True`, display a colorbar next to the plots.
 """
 
 # connected
@@ -305,28 +322,39 @@ cut_coords : None, allowed types depend on the ``display_mode``, optional
     The world coordinates of the point where the cut is performed.
 
     - If ``display_mode`` is ``'ortho'`` or ``'tiled'``,
-      this must be a 3 :obj:`tuple`
-      of :obj:`float` or :obj:`int`: ``(x, y, z)``.
+      this must be a 3-sequence of :obj:`float` or :obj:`int`:
+      ``(x, y, z)``.
 
-    - If ``display_mode`` is ``"x"``, ``"y"``, or ``"z"``
+    - If ``display_mode`` is ``'xz'``, ``'yz'`` or ``'yx'``,
+      this must be a 2-sequence of :obj:`float` or :obj:`int`:
+      ``(x, z)``,  ``(y, z)`` or  ``(x, y)``.
+
+    - If ``display_mode`` is ``"x"``, ``"y"``, or ``"z"``,
       this can be:
 
-      - an array-like of :obj:`float` or :obj:`int`
+      - a sequence of :obj:`float` or :obj:`int`
         representing the coordinates of each cut
         in the corresponding direction,
 
       - an :obj:`int`
         in which case it specifies the number of cuts to perform.
 
+    - If ``display_mode`` is ``'mosaic'``, this can be:
+
+      - an :obj:`int`
+        in which case it specifies the number of cuts to perform in each
+        direction ``"x"``, ``"y"``, ``"z"``.
+
+      - a 3-sequence of :obj:`float` or :obj:`int`
+        in which case it specifies the number of cuts to perform in each
+        direction ``"x"``, ``"y"``, ``"z"`` separately.
+
+      - :obj:`dict` <:obj:`str`: 1D :class:`~numpy.ndarray`>
+        in which case keys are the directions ('x', 'y', 'z') and the values
+        are sequences holding the cut coordinates.
+
     - If ``None`` is given, the cuts are calculated automatically.
 
-    - If ``display_mode`` is ``'mosaic'``, and the number of cuts is the same
-      for all directions, ``cut_coords`` can be specified as an :obj:`int`.
-      It can also be a length 3 :obj:`tuple` of  :obj:`int`
-      specifying the number of cuts for
-      every direction if these are different.
-
-
 """
 
 
@@ -651,7 +679,7 @@ keep_masked_labels : :obj:`bool`, default=False
 
     .. nilearn_deprecated:: 0.10.2
 
-    .. nilearn_versionchanged:: 0.13.0dev
+    .. nilearn_versionchanged:: 0.13.0
 
         The ``keep_masked_labels`` parameter will be removed in 0.15.
 
@@ -668,7 +696,7 @@ keep_masked_maps : :obj:`bool`, optional
 
     .. nilearn_deprecated:: 0.10.2
 
-    .. nilearn_versionchanged:: 0.13.0dev
+    .. nilearn_versionchanged:: 0.13.0
 
         The ``keep_masked_maps`` parameter will be removed in 0.15.
 
@@ -859,7 +887,7 @@ opening : :obj:`bool` or :obj:`int`, optional
 
 # output_file
 docdict["output_file"] = """
-output_file : :obj:`str` or :obj:`pathlib.Path` or None, optional
+output_file : :obj:`str` or :obj:`pathlib.Path` or None, default=None
     The name of an image file to export the plot to.
     Valid extensions are .png, .pdf, .svg.
     If `output_file` is not `None`, the plot is saved to a file,
@@ -1027,7 +1055,7 @@ second_level_contrast : :obj:`str` or :class:`numpy.ndarray` of shape\
 
 # second_level_confounds
 docdict["second_level_confounds"] = """
-confounds : :obj:`pandas.DataFrame` or None, default=None
+confounds : :obj:`pandas.DataFrame` or None, Default=None
     Must contain a ``subject_label`` column.
     All other columns are considered as confounds and included in the model.
     If ``design_matrix`` is provided then this argument is ignored.
@@ -1041,7 +1069,7 @@ confounds : :obj:`pandas.DataFrame` or None, default=None
 docdict["second_level_design_matrix"] = """
 design_matrix : :obj:`pandas.DataFrame`, :obj:`str` or \
                 or :obj:`pathlib.Path` to a CSV or TSV file, \
-                or None, default=None
+                or None, Default=None
     Design matrix to fit the :term:`GLM`.
     The number of rows in the design matrix
     must agree with the number of maps
@@ -1154,14 +1182,14 @@ standardize : any of: 'zscore_sample', 'zscore', 'psc', True, False or None; \
     - ``True``: The signal is z-scored (same as option `zscore`).
       Timeseries are shifted to zero mean and scaled to unit variance.
 
-      .. nilearn_deprecated:: 0.13.0dev
+      .. nilearn_deprecated:: 0.13.0
 
         In nilearn version 0.15.0,
         ``True`` will be replaced by  ``'zscore_sample'``.
 
     - ``False``: Do not standardize the data.
 
-      .. nilearn_deprecated:: 0.13.0dev
+      .. nilearn_deprecated:: 0.13.0
 
         In nilearn version 0.15.0,
         ``False`` will be replaced by ``None``.
@@ -1425,7 +1453,7 @@ vmax : :obj:`float` or obj:`int` or None, optional
 
 # vmin
 docdict["vmin"] = """
-vmin : :obj:`float`  or obj:`int` or None, optional
+vmin : :obj:`float` or obj:`int` or None, optional
     Lower bound of the colormap. The values below vmin are masked.
     If `None`, the min of the image is used.
     Passed to :func:`matplotlib.pyplot.imshow`.
@@ -1500,9 +1528,6 @@ masker_ :  :obj:`~nilearn.maskers.MultiNiftiMasker` or \
 
 memory_ : joblib memory cache
 
-n_elements_ : :obj:`int`
-    The number of components.
-
 """
 
 docdict["base_decoder_fit_attributes"] = """
@@ -1683,6 +1708,39 @@ ymean_ : array, shape (n_samples,)
 
 """
 
+docdict["displays_partial_attributes"] = """
+frame_axes : :class:`~matplotlib.axes.Axes`
+    The axes framing the whole set of views.
+
+rect : 4- :obj:`tuple`
+    Position of axes within the figure.
+"""
+
+docdict["slicer_init_parameters_partial"] = f"""
+{docdict["axes"]}
+{docdict["black_bg"]}
+{docdict["brain_color"]}
+kwargs : :obj:`dict`
+    Extra keyword arguments are passed to
+    :class:`~nilearn.plotting.displays.CutAxes` used for plotting in each
+    direction.
+"""
+
+docdict["projector_init_parameters"] = f"""
+Parameters
+----------
+cut_coords : sequence of :obj:`float` or :obj:`int`
+    The world coordinates of the point where the cut is performed. Not used
+    for projectors.
+{docdict["axes"]}
+{docdict["black_bg"]}
+{docdict["brain_color"]}
+kwargs : :obj:`dict`
+    Extra keyword arguments are passed to
+    :class:`~nilearn.plotting.displays.GlassBrainAxes` used for plotting in
+    each direction.
+"""
+
 # dataset description
 docdict["description"] = """'description' : :obj:`str`
         Description of the dataset."""
@@ -1756,7 +1814,7 @@ signals_transform = """signals : :obj:`numpy.ndarray`, \
 
         Signal for each element.
 
-        .. nilearn_versionchanged:: 0.13.0dev
+        .. nilearn_versionchanged:: 0.13.0
 
             Added ``set_output`` support.
 
@@ -1911,5 +1969,5 @@ def fill_doc(f):
         raise RuntimeError(
             f"Error documenting {funcname}:\n{exp!s}.\n"
             "Did you forget to escape a character with an extra '%'"
-        )
+        ) from exp
     return f
