@@ -132,61 +132,3 @@ def coerce_to_dict(input_arg):
             input_arg = [input_arg]
         input_arg = {str(contrast_): contrast_ for contrast_ in input_arg}
     return input_arg
-
-
-def make_stat_maps(
-    model, contrasts, output_type="z_score", first_level_contrast=None
-):
-    """Given a model and contrasts, return the corresponding z-maps.
-
-    Parameters
-    ----------
-    model : FirstLevelModel or SecondLevelModel object
-        Must have a fitted design matrix(ces).
-
-    contrasts : Dict[str, ndarray or str]
-        Dict of contrasts for a first or second level model.
-        Corresponds to the contrast_def for the FirstLevelModel
-        (nilearn.glm.first_level.FirstLevelModel.compute_contrast)
-        & second_level_contrast for a SecondLevelModel
-        (nilearn.glm.second_level.SecondLevelModel.compute_contrast)
-
-    output_type : :obj:`str`, default='z_score'
-        The type of statistical map to retain from the contrast.
-
-        .. versionadded:: 0.9.2
-
-    %(first_level_contrast)s
-
-        .. versionadded:: 0.12.0
-
-    Returns
-    -------
-    statistical_maps : Dict[str, niimg] or Dict[str, Dict[str, niimg]]
-        Dict of statistical z-maps keyed to contrast names/titles.
-
-    See Also
-    --------
-    nilearn.glm.first_level.FirstLevelModel.compute_contrast
-    nilearn.glm.second_level.SecondLevelModel.compute_contrast
-
-    """
-    from nilearn.glm.second_level import SecondLevelModel
-
-    if isinstance(model, SecondLevelModel):
-        return {
-            contrast_name: model.compute_contrast(
-                contrast_data,
-                output_type=output_type,
-                first_level_contrast=first_level_contrast,
-            )
-            for contrast_name, contrast_data in contrasts.items()
-        }
-
-    return {
-        contrast_name: model.compute_contrast(
-            contrast_data,
-            output_type=output_type,
-        )
-        for contrast_name, contrast_data in contrasts.items()
-    }
