@@ -6,7 +6,6 @@ import pytest
 
 from nilearn._utils.helpers import (
     _warn_deprecated_params,
-    compare_version,
     is_kaleido_installed,
     is_matplotlib_installed,
     is_plotly_installed,
@@ -71,6 +70,7 @@ def test_should_raise_warning_if_mpl_not_installed():
         set_mpl_backend()
 
 
+@pytest.mark.thread_unsafe
 @pytest.mark.skipif(
     not is_matplotlib_installed(),
     reason="Test requires matplotlib to be installed.",
@@ -84,6 +84,7 @@ def test_should_raise_warning_if_backend_changes(*_):
         set_mpl_backend()
 
 
+@pytest.mark.thread_unsafe
 @pytest.mark.skipif(
     not is_matplotlib_installed(),
     reason="Test requires matplotlib to be installed.",
@@ -98,6 +99,7 @@ def test_should_not_raise_warning_if_backend_is_not_changed(*_):
         set_mpl_backend()
 
 
+@pytest.mark.thread_unsafe
 @pytest.mark.skipif(
     not is_matplotlib_installed(),
     reason="Test requires matplotlib to be installed.",
@@ -115,6 +117,7 @@ def test_should_switch_to_agg_backend_if_current_backend_fails(use_mock):
     use_mock.assert_called_with("Agg")
 
 
+@pytest.mark.thread_unsafe
 @pytest.mark.skipif(
     not is_matplotlib_installed(),
     reason="Test requires matplotlib to be installed.",
@@ -125,6 +128,7 @@ def test_should_raise_import_error_for_version_check():
         set_mpl_backend()
 
 
+@pytest.mark.thread_unsafe
 def test_rename_parameters():
     """Test deprecated mock parameters in a mock function.
 
@@ -202,6 +206,7 @@ def test_transfer_deprecated_param_vals():
     assert actual_output == expected_output
 
 
+@pytest.mark.thread_unsafe
 def test_future_warn_deprecated_params():
     """Check that the correct warning is displayed."""
     mock_input, replacement_params = _mock_args_for_testing_replace_parameter()
@@ -233,28 +238,6 @@ def test_future_warn_deprecated_params():
         assert str(raised_warning_.message) == expected_warning_
 
 
-@pytest.mark.parametrize(
-    "version_a,operator,version_b",
-    [
-        ("0.1.0", ">", "0.0.1"),
-        ("0.1.0", ">=", "0.0.1"),
-        ("0.1", "==", "0.1.0"),
-        ("0.0.0", "<", "0.1.0"),
-        ("1.0", "!=", "0.1.0"),
-    ],
-)
-def test_compare_version(version_a, operator, version_b):
-    assert compare_version(version_a, operator, version_b)
-
-
-def test_compare_version_error():
-    with pytest.raises(
-        ValueError,
-        match=r"'compare_version' received an unexpected operator <>.",
-    ):
-        compare_version("0.1.0", "<>", "1.1.0")
-
-
 def test_is_plotly_installed():
     is_plotly_installed()
 
