@@ -8,6 +8,9 @@ from numpy.testing import assert_no_warnings
 
 from nilearn._utils import html_document
 
+#  import autoused fixture
+from nilearn.datasets.tests.conftest import request_mocker  # noqa: F401
+
 # Note: html output by nilearn view_* functions
 # should validate as html5 using https://validator.w3.org/nu/ with no
 # warnings
@@ -27,6 +30,7 @@ class Get:
         self.content = requests.get(url).content
 
 
+@pytest.mark.thread_unsafe
 # disable request mocking for this test -- note we are accessing localhost only
 @pytest.mark.parametrize("request_mocker", [None])
 def test_open_in_browser(monkeypatch):
@@ -37,6 +41,7 @@ def test_open_in_browser(monkeypatch):
     assert opener.content == b"hello"
 
 
+@pytest.mark.thread_unsafe
 def test_open_in_browser_timeout(monkeypatch):
     opener = Get(delay=1.0)
     monkeypatch.setattr(webbrowser, "open", opener)
@@ -46,6 +51,7 @@ def test_open_in_browser_timeout(monkeypatch):
         doc.open_in_browser()
 
 
+@pytest.mark.thread_unsafe
 def test_open_in_browser_file(tmp_path, monkeypatch):
     opener = Mock()
     monkeypatch.setattr(webbrowser, "open", opener)
@@ -66,10 +72,12 @@ def _open_one_view():
     return v
 
 
+@pytest.mark.thread_unsafe
 def test_open_view_warning():
     # opening many views (without deleting the SurfaceView objects)
     # should raise a warning about memory usage
-    pytest.warns(UserWarning, _open_views)
+    with pytest.warns(UserWarning):
+        _open_views()
     assert_no_warnings(_open_one_view)
     html_document.set_max_img_views_before_warning(15)
     assert_no_warnings(_open_views)
@@ -78,7 +86,8 @@ def test_open_view_warning():
     html_document.set_max_img_views_before_warning(None)
     assert_no_warnings(_open_views)
     html_document.set_max_img_views_before_warning(6)
-    pytest.warns(UserWarning, _open_views)
+    with pytest.warns(UserWarning):
+        _open_views()
 
 
 def test_repr():
