@@ -19,6 +19,7 @@ from nilearn._utils.bids import (
 )
 from nilearn._utils.docs import fill_doc
 from nilearn._utils.helpers import rename_parameters
+from nilearn._utils.niimg import _get_data
 from nilearn._utils.param_validation import (
     check_parameter_in_allowed,
     check_params,
@@ -30,7 +31,6 @@ from nilearn.datasets._utils import (
     get_dataset_dir,
 )
 from nilearn.image import check_niimg, new_img_like, reorder_img
-from nilearn.image import get_data as get_img_data
 
 _TALAIRACH_LEVELS = ["hemisphere", "lobe", "gyrus", "tissue", "ba"]
 
@@ -715,7 +715,7 @@ def fetch_atlas_juelich(
         verbose=verbose,
     )
     atlas_niimg = check_niimg(atlas_img)
-    atlas_data = get_img_data(atlas_niimg)
+    atlas_data = _get_data(atlas_niimg)
 
     if atlas_type == "probabilistic":
         new_atlas_data, new_names = _merge_probabilistic_maps_juelich(
@@ -870,7 +870,7 @@ def _compute_symmetric_split(source, atlas_niimg, names):
     # should be positive. This is important to
     # correctly split left and right hemispheres.
     assert atlas_niimg.affine[0, 0] > 0
-    atlas_data = get_img_data(atlas_niimg)
+    atlas_data = _get_data(atlas_niimg)
     labels = np.unique(atlas_data)
     # Build a mask of both halves of the brain
     middle_ind = (atlas_data.shape[0]) // 2
@@ -1355,7 +1355,7 @@ def fetch_atlas_aal(
         The version of the AAL atlas. Must be 'SPM5', 'SPM8', 'SPM12', or '3v2'
         for the latest SPM12 version of AAL3 software.
 
-        .. nilearn_versionchanged:: 0.13.0dev
+        .. nilearn_versionchanged:: 0.13.0
 
           The default was changed to '3v2'.
 
@@ -1531,7 +1531,7 @@ def fetch_atlas_basc_multiscale_2015(
         Valid resolutions available are
         {7, 12, 20, 36, 64, 122, 197, 325, 444}
 
-        .. nilearn_versionchanged: 0.13.0dev
+        .. nilearn_versionchanged: 0.13.0
 
           Default changed to ``7``.
 
@@ -2013,6 +2013,7 @@ def _separate_talairach_levels(atlas_img, labels, output_dir, verbose):
         f"Separating talairach atlas levels: {_TALAIRACH_LEVELS}",
         verbose=verbose,
     )
+    atlas_data = _get_data(atlas_img)
     for level_name, old_level_labels in zip(
         _TALAIRACH_LEVELS, np.asarray(labels).T, strict=False
     ):
@@ -2022,9 +2023,7 @@ def _separate_talairach_levels(atlas_img, labels, output_dir, verbose):
         level_labels = {"*": 0}
         for region_nb, region_name in enumerate(old_level_labels):
             level_labels.setdefault(region_name, len(level_labels))
-            level_data[get_img_data(atlas_img) == region_nb] = level_labels[
-                region_name
-            ]
+            level_data[atlas_data == region_nb] = level_labels[region_name]
         new_img_like(atlas_img, level_data).to_filename(
             output_dir / f"{level_name}.nii.gz"
         )
@@ -2037,7 +2036,7 @@ def _separate_talairach_levels(atlas_img, labels, output_dir, verbose):
         )
 
 
-def _download_talairach(talairach_dir, verbose):
+def _download_talairach(talairach_dir, verbose) -> None:
     """Download the Talairach atlas and separate the different levels."""
     atlas_url = "https://www.talairach.org/talairach.nii"
     temp_dir = mkdtemp()
@@ -2047,14 +2046,14 @@ def _download_talairach(talairach_dir, verbose):
         )[0]
         atlas_img = load(temp_file, mmap=False)
         atlas_img = check_niimg(atlas_img)
+        labels_text = atlas_img.header.extensions[0].get_content()
+        multi_labels = labels_text.strip().decode("utf-8").split("\n")
+        labels = [lab.split(".") for lab in multi_labels]
+        _separate_talairach_levels(
+            atlas_img, labels, talairach_dir, verbose=verbose
+        )
     finally:
         shutil.rmtree(temp_dir)
-    labels_text = atlas_img.header.extensions[0].get_content()
-    multi_labels = labels_text.strip().decode("utf-8").split("\n")
-    labels = [lab.split(".") for lab in multi_labels]
-    _separate_talairach_levels(
-        atlas_img, labels, talairach_dir, verbose=verbose
-    )
 
 
 @fill_doc
