@@ -7,7 +7,7 @@ from nilearn._utils.docs import fill_doc
 from nilearn._utils.param_validation import (
     check_params,
 )
-from nilearn._utils.tags import SKLEARN_LT_1_6
+from nilearn._utils.versions import SKLEARN_LT_1_6
 
 
 class _ClassifierMixin:
