@@ -45,17 +45,14 @@ from sklearn.model_selection import (
 )
 from sklearn.preprocessing import LabelBinarizer, StandardScaler
 from sklearn.svm import SVR, LinearSVC
-from sklearn.utils.estimator_checks import (
-    ignore_warnings,
-    parametrize_with_checks,
-)
+from sklearn.utils.estimator_checks import parametrize_with_checks
 
 from nilearn._utils.estimator_checks import (
     check_estimator,
     nilearn_check_estimator,
     return_expected_failed_checks,
 )
-from nilearn._utils.tags import SKLEARN_LT_1_6
+from nilearn._utils.versions import SKLEARN_GTE_1_7, SKLEARN_LT_1_6
 from nilearn.conftest import _rng
 from nilearn.decoding import (
     Decoder,
@@ -63,10 +60,7 @@ from nilearn.decoding import (
     FREMClassifier,
     FREMRegressor,
 )
-from nilearn.decoding._utils import (
-    _get_mask_extent,
-    check_feature_screening,
-)
+from nilearn.decoding._utils import _get_mask_extent, check_feature_screening
 from nilearn.decoding.decoder import (
     SUPPORTED_ESTIMATORS,
     _BaseDecoder,
@@ -74,6 +68,7 @@ from nilearn.decoding.decoder import (
     _check_param_grid,
     _parallel_fit,
     _wrap_param_grid,
+    kwarg_logistic_regression_cv,
 )
 from nilearn.decoding.tests.test_same_api import to_niimgs
 from nilearn.maskers import NiftiMasker, SurfaceMasker
@@ -228,8 +223,18 @@ def test_check_param_grid_regression(regressor, param, rng):
 @pytest.mark.parametrize(
     "classifier, param",
     [
-        (LogisticRegressionCV(penalty="l1"), ["Cs"]),
-        (LogisticRegressionCV(penalty="l2"), ["Cs"]),
+        (
+            LogisticRegressionCV(
+                l1_ratios=(1,), **kwarg_logistic_regression_cv
+            ),
+            ["Cs"],
+        ),
+        (
+            LogisticRegressionCV(
+                l1_ratios=(0,), **kwarg_logistic_regression_cv
+            ),
+            ["Cs"],
+        ),
         (RidgeClassifierCV(), ["alphas"]),
     ],
 )
@@ -245,7 +250,6 @@ def test_check_param_grid_classification(rand_x_y, classifier, param):
     assert list(param_grid.keys()) == list(param)
 
 
-@ignore_warnings
 @pytest.mark.parametrize(
     "param_grid_input",
     [
@@ -258,12 +262,31 @@ def test_check_param_grid_replacement(rand_x_y, param_grid_input):
     X, Y = rand_x_y
     param_to_replace = "C"
     param_replaced = "Cs"
-    param_grid_output = _check_param_grid(
-        LogisticRegressionCV(),
-        X,
-        Y,
-        param_grid_input,
-    )
+    if "C" in param_grid_input or (
+        isinstance(param_grid_input, list)
+        and any("C" in x for x in param_grid_input)
+    ):
+        with pytest.warns(
+            FutureWarning,
+            match="change in the choice of underlying scikit-learn estimator",
+        ):
+            param_grid_output = _check_param_grid(
+                LogisticRegressionCV(
+                    l1_ratios=(0.0,), **kwarg_logistic_regression_cv
+                ),
+                X,
+                Y,
+                param_grid_input,
+            )
+    else:
+        param_grid_output = _check_param_grid(
+            LogisticRegressionCV(
+                l1_ratios=(0.0,), **kwarg_logistic_regression_cv
+            ),
+            X,
+            Y,
+            param_grid_input,
+        )
     for params in ParameterGrid(param_grid_output):
         assert param_to_replace not in params
         if param_replaced not in params:
@@ -290,7 +313,6 @@ def test_check_parameter_grid_is_empty(rand_x_y):
     assert param_grid == {}
 
 
-@ignore_warnings
 @pytest.mark.parametrize(
     "param_grid",
     [
@@ -489,7 +511,6 @@ def test_parallel_fit(rand_x_y):
             assert a == b
 
 
-@ignore_warnings
 @pytest.mark.parametrize(
     "param_values",
     (
@@ -502,7 +523,14 @@ def test_parallel_fit(rand_x_y):
     [
         (RidgeCV(), "alphas", "best_alpha", False),
         (RidgeClassifierCV(), "alphas", "best_alpha", True),
-        (LogisticRegressionCV(), "Cs", "best_C", True),
+        (
+            LogisticRegressionCV(
+                l1_ratios=(0,), **kwarg_logistic_regression_cv
+            ),
+            "Cs",
+            "best_C",
+            True,
+        ),
         (LassoCV(), "alphas", "best_alpha", False),
     ],
 )
@@ -562,7 +590,6 @@ def test_parallel_fit_builtin_cv(
     assert isinstance(best_param[fitted_param_name], numbers.Number)
 
 
-@ignore_warnings
 def test_decoder_param_grid_sequence(binary_classification_data):
     X, y, _ = binary_classification_data
     n_cv_folds = 10
@@ -590,7 +617,6 @@ def test_decoder_param_grid_sequence(binary_classification_data):
             assert len(param_list) == n_cv_folds
 
 
-@ignore_warnings
 def test_decoder_binary_classification_with_masker_object(
     binary_classification_data,
 ):
@@ -605,7 +631,6 @@ def test_decoder_binary_classification_with_masker_object(
     assert accuracy_score(y, y_pred) > 0.95
 
 
-@ignore_warnings
 def test_decoder_binary_classification_with_logistic_model(
     binary_classification_data,
 ):
@@ -621,7 +646,7 @@ def test_decoder_binary_classification_with_logistic_model(
     assert accuracy_score(y, y_pred) > 0.95
 
 
-@ignore_warnings
+@pytest.mark.slow
 @pytest.mark.parametrize("screening_percentile", [100, 20, None])
 def test_decoder_binary_classification_screening(
     binary_classification_data, screening_percentile
@@ -639,7 +664,6 @@ def test_decoder_binary_classification_screening(
     assert accuracy_score(y, y_pred) > 0.95
 
 
-@ignore_warnings
 @pytest.mark.parametrize("clustering_percentile", [100, 99])
 def test_decoder_binary_classification_clustering(
     binary_classification_data, clustering_percentile
@@ -660,7 +684,7 @@ def test_decoder_binary_classification_clustering(
     assert accuracy_score(y, y_pred) > 0.9
 
 
-@ignore_warnings
+@pytest.mark.thread_unsafe
 @pytest.mark.slow
 @pytest.mark.parametrize(
     "estimator, data",
@@ -716,7 +740,6 @@ def test_cross_validation(estimator, data, cv):
         assert r2_score(y, y_pred) > 0.9
 
 
-@ignore_warnings
 @pytest.mark.slow
 def test_decoder_dummy_classifier(binary_classification_data):
     n_samples = N_SAMPLES
@@ -737,7 +760,6 @@ def test_decoder_dummy_classifier(binary_classification_data):
     assert np.sum(y_pred == 1.0) / n_samples - proportion < 0.05
 
 
-@ignore_warnings
 def test_decoder_dummy_classifier_with_callable(binary_classification_data):
     X, y, mask = binary_classification_data
 
@@ -755,7 +777,6 @@ def test_decoder_dummy_classifier_with_callable(binary_classification_data):
     assert model.score(X, y) == accuracy_score(y, y_pred)
 
 
-@ignore_warnings
 def test_decoder_dummy_classifier_strategy_prior():
     X, y, mask = _make_binary_classification_test_data(n_samples=300)
 
@@ -772,7 +793,6 @@ def test_decoder_dummy_classifier_strategy_prior():
     assert roc_auc_score(y, y_pred) == 0.5
 
 
-@ignore_warnings
 def test_decoder_dummy_classifier_strategy_most_frequent():
     X, y, mask = _make_binary_classification_test_data(n_samples=300)
 
@@ -795,7 +815,6 @@ def test_decoder_dummy_classifier_strategy_most_frequent():
     assert model.cv_scores_ is not None
 
 
-@ignore_warnings
 def test_decoder_dummy_classifier_roc_scoring(binary_classification_data):
     X, y, mask = binary_classification_data
 
@@ -810,7 +829,7 @@ def test_decoder_dummy_classifier_roc_scoring(binary_classification_data):
     assert np.mean(model.cv_scores_[0]) >= 0.45
 
 
-@ignore_warnings
+@pytest.mark.slow
 def test_decoder_error_not_implemented(tiny_binary_classification_data):
     X, y, mask = tiny_binary_classification_data
 
@@ -826,7 +845,6 @@ def test_decoder_error_not_implemented(tiny_binary_classification_data):
         model.fit(X, y)
 
 
-@ignore_warnings
 def test_decoder_error_unknown_scoring_metrics(
     tiny_binary_classification_data,
 ):
@@ -848,7 +866,6 @@ def test_decoder_error_unknown_scoring_metrics(
         model.fit(X, y)
 
 
-@ignore_warnings
 def test_decoder_dummy_classifier_default_scoring():
     X, y, _ = _make_binary_classification_test_data()
 
@@ -865,7 +882,7 @@ def test_decoder_dummy_classifier_default_scoring():
     assert model.score(X, y) > 0.5
 
 
-@ignore_warnings
+@pytest.mark.slow
 def test_decoder_classification_string_label():
     iris = load_iris()
     X, y = iris.data, iris.target
@@ -880,7 +897,7 @@ def test_decoder_classification_string_label():
     assert accuracy_score(y_str, y_pred) > 0.95
 
 
-@ignore_warnings
+@pytest.mark.slow
 @pytest.mark.parametrize("screening_percentile", [100, 20, 1, None])
 @pytest.mark.parametrize("estimator", ESTIMATOR_REGRESSION)
 def test_decoder_regression_screening(
@@ -900,7 +917,7 @@ def test_decoder_regression_screening(
     assert r2_score(y, y_pred) > 0.95
 
 
-@ignore_warnings
+@pytest.mark.slow
 @pytest.mark.parametrize("clustering_percentile", [100, 99])
 @pytest.mark.parametrize("estimator", ESTIMATOR_REGRESSION)
 def test_decoder_regression_clustering(
@@ -924,7 +941,6 @@ def test_decoder_regression_clustering(
     assert model.score(X, y) == r2_score(y, y_pred)
 
 
-@ignore_warnings
 def test_decoder_dummy_regression(regression_data):
     X, y, mask = regression_data
 
@@ -944,7 +960,6 @@ def test_decoder_dummy_regression(regression_data):
     assert model.score(X, y) == r2_score(y, y_pred)
 
 
-@ignore_warnings
 def test_decoder_dummy_regression_default_scoring_metric_is_r2(
     regression_data,
 ):
@@ -963,7 +978,6 @@ def test_decoder_dummy_regression_default_scoring_metric_is_r2(
     assert model.score(X, y) == r2_score(y, y_pred)
 
 
-@ignore_warnings
 def test_decoder_dummy_regression_other_strategy(regression_data):
     """Chexk that decoder object use other strategy for dummy regressor."""
     X, y, mask = regression_data
@@ -986,7 +1000,6 @@ def test_decoder_dummy_regression_other_strategy(regression_data):
     assert model.cv_scores_ is not None
 
 
-@ignore_warnings
 @pytest.mark.slow
 def test_decoder_multiclass_classification_masker(multiclass_data):
     X, y, _ = multiclass_data
@@ -998,7 +1011,7 @@ def test_decoder_multiclass_classification_masker(multiclass_data):
     assert accuracy_score(y, y_pred) > 0.95
 
 
-@ignore_warnings
+@pytest.mark.slow
 def test_decoder_multiclass_classification_masker_dummy_classifier(
     multiclass_data,
 ):
@@ -1019,7 +1032,6 @@ def test_decoder_multiclass_classification_masker_dummy_classifier(
     assert model.score(X, y) == accuracy_score(y, y_pred)
 
 
-@ignore_warnings
 @pytest.mark.slow
 @pytest.mark.parametrize("screening_percentile", [100, 20, None])
 def test_decoder_multiclass_classification_screening(
@@ -1038,7 +1050,6 @@ def test_decoder_multiclass_classification_screening(
     assert accuracy_score(y, y_pred) > 0.95
 
 
-@ignore_warnings
 @pytest.mark.slow
 @pytest.mark.parametrize("clustering_percentile", [100, 99])
 @pytest.mark.parametrize("estimator", ["svc_l2", "svc_l1"])
@@ -1062,6 +1073,7 @@ def test_decoder_multiclass_classification_clustering(
     assert accuracy_score(y, y_pred) > 0.9
 
 
+@pytest.mark.slow
 def test_decoder_multiclass_classification_apply_mask_shape():
     """Test whether if _apply mask output has the same shape \
     as original matrix.
@@ -1119,17 +1131,18 @@ def test_decoder_multiclass_classification_apply_mask_attributes(affine_eye):
     assert model.masker_.smoothing_fwhm == smoothing_fwhm
 
 
+@pytest.mark.thread_unsafe
 def test_decoder_multiclass_error_incorrect_cv(multiclass_data):
     """Check whether ValueError is raised when cv is not set correctly."""
     X, y, _ = multiclass_data
 
     for cv in ["abc", LinearSVC(dual=True)]:
         model = Decoder(mask=NiftiMasker(), cv=cv, standardize="zscore_sample")
-        with pytest.raises(ValueError, match="Expected cv as an integer"):
+        with pytest.raises(ValueError, match=r"Expected .* as an integer"):
             model.fit(X, y)
 
 
-@ignore_warnings
+@pytest.mark.slow
 def test_decoder_multiclass_warnings_decoder(multiclass_data):
     """Check whether decoder raised warning \
         when groups is set to specific value but CV Splitter is not set.
@@ -1147,7 +1160,6 @@ def test_decoder_multiclass_warnings_decoder(multiclass_data):
         model.fit(X, y, groups=groups)
 
 
-@ignore_warnings
 def test_decoder_multiclass_warnings_frem(multiclass_data):
     """Check that warning is raised \
         when n_features is lower than 50 after \
@@ -1187,7 +1199,6 @@ def test_decoder_tags_regression():
         assert model.__sklearn_tags__().target_tags.multi_output is True
 
 
-@ignore_warnings
 @pytest.mark.slow
 def test_decoder_strings_filepaths_input(
     tiny_binary_classification_data, tmp_path
@@ -1234,7 +1245,6 @@ def test_decoder_apply_mask_surface(_make_surface_class_data):
     assert type(model.mask_img_).__name__ == "SurfaceImage"
 
 
-@ignore_warnings
 def test_decoder_screening_percentile_surface_default(
     _make_surface_class_data,
 ):
@@ -1246,7 +1256,7 @@ def test_decoder_screening_percentile_surface_default(
     assert model.screening_percentile_ == 20
 
 
-@ignore_warnings
+@pytest.mark.thread_unsafe
 @pytest.mark.parametrize("perc", [None, 100, 0])
 def test_decoder_screening_percentile_surface(perc, _make_surface_class_data):
     """Test passing screening percentile with surface image."""
@@ -1264,7 +1274,7 @@ def test_decoder_screening_percentile_surface(perc, _make_surface_class_data):
         assert model.screening_percentile_ == perc
 
 
-@ignore_warnings
+@pytest.mark.thread_unsafe
 @pytest.mark.parametrize("surf_mask_dim", [1, 2])
 def test_decoder_adjust_screening_less_than_mask_surface(
     surf_mask_dim,
@@ -1296,7 +1306,7 @@ def test_decoder_adjust_screening_less_than_mask_surface(
     )
 
 
-@ignore_warnings
+@pytest.mark.thread_unsafe
 @pytest.mark.parametrize("surf_mask_dim", [1, 2])
 def test_decoder_adjust_screening_greater_than_mask_surface(
     surf_mask_dim,
@@ -1326,7 +1336,6 @@ def test_decoder_adjust_screening_greater_than_mask_surface(
     assert adjusted == 100
 
 
-@ignore_warnings
 def test_decoder_predict_score_surface(_make_surface_class_data):
     """Test classification predict and scoring for surface image."""
     X, y = _make_surface_class_data
@@ -1341,7 +1350,6 @@ def test_decoder_predict_score_surface(_make_surface_class_data):
     assert 0.3 < acc < 0.7
 
 
-@ignore_warnings
 def test_decoder_regressor_predict_score_surface(_make_surface_reg_data):
     """Test regression predict and scoring for surface image."""
     X, y = _make_surface_reg_data
@@ -1356,7 +1364,6 @@ def test_decoder_regressor_predict_score_surface(_make_surface_reg_data):
     assert r2 <= 0
 
 
-@ignore_warnings
 @pytest.mark.parametrize("frem", [FREMRegressor, FREMClassifier])
 def test_frem_decoder_fit_surface(
     frem,
@@ -1376,7 +1383,7 @@ def test_frem_decoder_fit_surface(
 # ------------------------ test decoder vs sklearn -------------------------- #
 
 
-@ignore_warnings
+@pytest.mark.thread_unsafe
 @pytest.mark.slow
 @pytest.mark.parametrize(
     "classifier_penalty",
@@ -1464,7 +1471,7 @@ def _set_best_hyperparameters(
         sklearn_classifier = clone(sklearn_classifier).set_params(
             Cs=nilearn_decoder.cv_params_[klass]["Cs"][count],
         )
-    elif classifier_penalty in ["ridge_classifier"]:
+    elif classifier_penalty == "ridge_classifier":
         # same as logistic regression
         sklearn_classifier = clone(sklearn_classifier).set_params(
             alphas=nilearn_decoder.cv_params_[klass]["alphas"][count]
@@ -1472,7 +1479,6 @@ def _set_best_hyperparameters(
     return sklearn_classifier
 
 
-@ignore_warnings
 @pytest.mark.slow
 @pytest.mark.parametrize("regressor", ["svr", "lasso", "ridge"])
 def test_regressor_vs_sklearn(
@@ -1496,7 +1502,15 @@ def test_regressor_vs_sklearn(
         scoring=scorer,
         screening_percentile=100,  # disable screening
     )
-    nilearn_regressor.fit(X, y)
+    if regressor == "lasso" and SKLEARN_GTE_1_7:
+        # TODO
+        # see https://github.com/nilearn/nilearn/issues/5452
+        with pytest.warns(
+            FutureWarning, match="'n_alphas' was deprecated in 1.7"
+        ):
+            nilearn_regressor.fit(X, y)
+    else:
+        nilearn_regressor.fit(X, y)
     scores_nilearn = nilearn_regressor.cv_scores_["beta"]
 
     # start decoding with sklearn
@@ -1519,12 +1533,13 @@ def test_regressor_vs_sklearn(
         elif regressor == "lasso":
             # this sets n_alphas as coded within nilearn and
             # LassoCV will select the best one using cross-validation
-            sklearn_regressor = clone(sklearn_regressor).set_params(
-                n_alphas=nilearn_regressor.cv_params_["beta"]["n_alphas"][
-                    count
-                ],
-            )
-        elif regressor in ["ridge"]:
+            tmp = nilearn_regressor.cv_params_["beta"]["n_alphas"][count]
+            sklearn_regressor = clone(sklearn_regressor)
+            if SKLEARN_GTE_1_7:
+                sklearn_regressor.set_params(alphas=tmp)
+            else:
+                sklearn_regressor.set_params(n_alphas=tmp)
+        elif regressor == "ridge":
             # same as lasso but with alphas
             sklearn_regressor = clone(sklearn_regressor).set_params(
                 alphas=nilearn_regressor.cv_params_["beta"]["alphas"][count]
