@@ -14,7 +14,7 @@ from nilearn._utils.estimator_checks import (
     nilearn_check_estimator,
     return_expected_failed_checks,
 )
-from nilearn._utils.tags import SKLEARN_LT_1_6
+from nilearn._utils.versions import SKLEARN_LT_1_6
 from nilearn.conftest import _rng
 from nilearn.decoding import searchlight
 
@@ -255,6 +255,7 @@ def test_mask_img_dimension_mismatch():
     assert sl.scores_.shape == invalid_mask_img.shape
 
 
+@pytest.mark.slow
 def test_transform_applies_mask_correctly():
     """Test if `transform()` applies the mask correctly."""
     frames = 20
