@@ -11,6 +11,7 @@ from nilearn.maskers import NiftiMasker, SurfaceMasker
 from nilearn.surface.surface import get_data as get_surface_data
 
 
+@pytest.mark.slow
 @pytest.mark.parametrize("data_type", ["nifti", "surface"])
 @pytest.mark.parametrize("n_epochs", [1, 2, 10])
 def test_check_values_epoch_argument_smoke(
@@ -34,6 +35,7 @@ def test_check_values_epoch_argument_smoke(
         mask=decomposition_mask_img,
         n_epochs=n_epochs,
         smoothing_fwhm=None,
+        standardize="zscore_sample",
         alpha=1,
     )
     dict_learning.fit(canica_data)
@@ -41,7 +43,7 @@ def test_check_values_epoch_argument_smoke(
     check_decomposition_estimator(dict_learning, data_type)
 
 
-@pytest.mark.timeout(0)
+@pytest.mark.slow
 @pytest.mark.parametrize("data_type", ["nifti"])
 def test_dict_learning(
     decomposition_mask_img, canica_components, canica_data, data_type
@@ -63,6 +65,7 @@ def test_dict_learning(
         dict_init=dict_init,
         mask=decomposition_mask_img,
         smoothing_fwhm=smoothing_fwhm,
+        standardize="zscore_sample",
         alpha=1,
     )
 
@@ -72,6 +75,7 @@ def test_dict_learning(
         mask=decomposition_mask_img,
         n_epochs=10,
         smoothing_fwhm=smoothing_fwhm,
+        standardize="zscore_sample",
         alpha=1,
     )
     maps = {}
@@ -101,6 +105,7 @@ def test_dict_learning(
         assert recovered_maps >= 2
 
 
+@pytest.mark.slow
 @pytest.mark.parametrize("data_type", ["nifti", "surface"])
 def test_component_sign(
     decomposition_mask_img, canica_data, data_type
@@ -117,6 +122,7 @@ def test_component_sign(
         random_state=RANDOM_STATE,
         mask=decomposition_mask_img,
         smoothing_fwhm=None,
+        standardize="zscore_sample",
         alpha=1,
     )
     dict_learning.fit(canica_data)
