@@ -20,7 +20,7 @@ from nilearn._utils.logger import find_stack_level
 from nilearn._utils.param_validation import check_is_of_allowed_type
 
 
-def check_events(events):
+def check_events(events: pd.DataFrame) -> pd.DataFrame:
     """Test that the events data describes a valid experimental paradigm.
 
     It is valid if the events data has ``'onset'`` and ``'duration'`` keys
@@ -97,7 +97,7 @@ def check_events(events):
     return _handle_modulation(events_copy)
 
 
-def _check_columns(events):
+def _check_columns(events: pd.DataFrame) -> pd.DataFrame:
     """Check events has onset and duration numeric columns with no NaN."""
     for col_name in ["onset", "duration"]:
         if col_name not in events.columns:
@@ -119,7 +119,7 @@ def _check_columns(events):
     return events
 
 
-def _handle_missing_trial_types(events):
+def _handle_missing_trial_types(events: pd.DataFrame) -> pd.DataFrame:
     """Create 'dummy' events trial_type if the column is not present."""
     if "trial_type" not in events.columns:
         warnings.warn(
@@ -130,7 +130,7 @@ def _handle_missing_trial_types(events):
     return events
 
 
-def _check_null_duration(events):
+def _check_null_duration(events: pd.DataFrame) -> None:
     """Warn if there are events with null duration."""
     conditions_with_null_duration = events["trial_type"][
         events["duration"] == 0
@@ -139,17 +139,16 @@ def _check_null_duration(events):
         ordered_list = [
             f"- '{x}'\n" for x in sorted(conditions_with_null_duration)
         ]
-        ordered_list = "".join(ordered_list)
         warnings.warn(
             (
                 "The following conditions contain events with null duration:\n"
-                f"{ordered_list}"
+                f"{''.join(ordered_list)}"
             ),
             stacklevel=find_stack_level(),
         )
 
 
-def _handle_modulation(events):
+def _handle_modulation(events: pd.DataFrame) -> pd.DataFrame:
     """Set the modulation column to 1 if it is not present."""
     if "modulation" in events.columns:
         logger.log(
@@ -165,7 +164,7 @@ def _handle_modulation(events):
 VALID_FIELDS = {"onset", "duration", "trial_type", "modulation"}
 
 
-def _check_unexpected_columns(events):
+def _check_unexpected_columns(events: pd.DataFrame) -> None:
     """Warn for each unexpected column that will not be used afterwards."""
     unexpected_columns = list(set(events.columns).difference(VALID_FIELDS))
     if unexpected_columns:
@@ -188,7 +187,9 @@ COLUMN_DEFINING_EVENT_IDENTITY = ["trial_type", "onset", "duration"]
 STRATEGY = {"modulation": "sum"}
 
 
-def handle_modulation_of_duplicate_events(events):
+def handle_modulation_of_duplicate_events(
+    events: pd.DataFrame,
+) -> pd.DataFrame:
     """Deal with modulation of duplicate events if they have one.
 
     Currently the strategy is to sum the modulation values of duplicate events.
