@@ -553,7 +553,7 @@ def _regressor_names(con_name, hrf_model, fir_delays=None):
     con_name : :obj:`str`
         identifier of the condition
     %(hrf_model)s
-    fir_delays : 1D array_like, optional
+    fir_delays : 1D array_like or None, default=None
         Delays (in scans) used in case of an FIR model
 
     Returns
@@ -608,7 +608,7 @@ def _hrf_kernel(hrf_model, t_r, oversampling=50, fir_delays=None):
     oversampling : :obj:`int`, default=50
         Temporal oversampling factor to have a smooth hrf.
 
-    fir_delays : 1D-array-like, optional
+    fir_delays : 1D-array-like or None, default=None
         List of delays (in scans) for finite impulse response models.
 
     Returns
@@ -671,15 +671,15 @@ def _hrf_kernel(hrf_model, t_r, oversampling=50, fir_delays=None):
     elif callable(hrf_model):
         try:
             hkernel = [hrf_model(t_r, oversampling)]
-        except TypeError:
-            raise ValueError(error_msg)
+        except TypeError as e:
+            raise ValueError(error_msg) from e
     elif isinstance(hrf_model, Iterable) and all(
         callable(_) for _ in hrf_model
     ):
         try:
             hkernel = [model(t_r, oversampling) for model in hrf_model]
-        except TypeError:
-            raise ValueError(error_msg)
+        except TypeError as e:
+            raise ValueError(error_msg) from e
     elif hrf_model is None:
         hkernel = [np.hstack((1, np.zeros(oversampling - 1)))]
     else:
