@@ -25,7 +25,7 @@ from nilearn._utils.estimator_checks import (
     nilearn_check_estimator,
     return_expected_failed_checks,
 )
-from nilearn._utils.tags import SKLEARN_LT_1_6
+from nilearn._utils.versions import SKLEARN_LT_1_6
 from nilearn.conftest import _shape_3d_default
 from nilearn.exceptions import NotImplementedWarning
 from nilearn.glm.first_level import FirstLevelModel, run_glm
@@ -44,6 +44,7 @@ from nilearn.glm.second_level.second_level import (
 from nilearn.image import concat_imgs, get_data, new_img_like, smooth_img
 from nilearn.maskers import NiftiMasker, SurfaceMasker
 from nilearn.reporting import get_clusters_table
+from nilearn.surface import SurfaceImage
 from nilearn.surface.utils import assert_surface_image_equal
 
 ESTIMATORS_TO_CHECK = [SecondLevelModel()]
@@ -142,6 +143,7 @@ def test_non_parametric_inference_with_flm_objects(shape_3d_default):
     )
 
 
+@pytest.mark.thread_unsafe
 def test_process_second_level_input_as_dataframe(input_df):
     """Unit tests for function _process_second_level_input_as_dataframe()."""
     sample_map, subjects_label = _process_second_level_input_as_dataframe(
@@ -554,6 +556,19 @@ def test_infer_effect_maps_error(tmp_path, shape_3d_default):
         _infer_effect_maps(second_level_input, "b")
 
 
+def test_mask_img_volume(n_subjects):
+    """Check mask_img_ with volume data."""
+    func_img, mask = fake_fmri_data()
+
+    model = SecondLevelModel(mask_img=mask)
+
+    Y = [func_img] * n_subjects
+    X = pd.DataFrame([[1]] * n_subjects, columns=["intercept"])
+    model = model.fit(Y, design_matrix=X)
+
+    assert isinstance(model._mask_img, Nifti1Image)
+
+
 @pytest.mark.slow
 def test_affine_output_mask(n_subjects):
     func_img, mask = fake_fmri_data()
@@ -1510,6 +1525,8 @@ def test_second_level_input_as_surface_image(surf_img_1d, n_subjects):
     model = SecondLevelModel()
     model = model.fit(second_level_input, design_matrix=design_matrix)
 
+    assert isinstance(model._mask_img, SurfaceImage)
+
 
 def test_second_level_input_as_surface_image_3d(surf_img_2d, n_subjects):
     """Fit with surface image with all subjects as timepoints."""
@@ -1535,6 +1552,7 @@ def test_second_level_input_error_surface_image_2d(surf_img_2d):
         model.fit(second_level_input, design_matrix=design_matrix)
 
 
+@pytest.mark.thread_unsafe
 def test_second_level_input_as_surface_image_3d_same_as_list_2d(
     surf_img_1d, n_subjects
 ):
@@ -1568,6 +1586,7 @@ def test_second_level_input_as_surface_no_design_matrix(
         model.fit(second_level_input, design_matrix=None)
 
 
+@pytest.mark.thread_unsafe
 @pytest.mark.parametrize("surf_mask_dim", [1, 2])
 def test_second_level_input_as_surface_image_with_mask(
     surf_img_1d, surf_mask_dim, surf_mask_1d, surf_mask_2d, n_subjects
@@ -1584,6 +1603,7 @@ def test_second_level_input_as_surface_image_with_mask(
     model = model.fit(second_level_input, design_matrix=design_matrix)
 
 
+@pytest.mark.thread_unsafe
 def test_second_level_input_with_wrong_mask(
     surf_img_1d, surf_mask_1d, img_mask_mni, n_subjects
 ):
@@ -1647,6 +1667,7 @@ def test_second_level_input_as_flm_of_surface_image(
     model = model.fit(second_level_input, design_matrix=design_matrix)
 
 
+@pytest.mark.thread_unsafe
 def test_second_level_surface_image_contrast_computation(
     surf_img_1d, n_subjects
 ):
@@ -1688,6 +1709,7 @@ def test_second_level_surface_image_contrast_computation(
         )
 
 
+@pytest.mark.thread_unsafe
 @pytest.mark.parametrize("two_sided_test", [True, False])
 def test_non_parametric_inference_with_surface_images(
     surf_img_1d, two_sided_test, n_subjects
