@@ -419,6 +419,7 @@ def test_resampling_warning_s_form(data, affine_eye, force_resample):
         )
 
 
+@pytest.mark.thread_unsafe
 @pytest.mark.parametrize("force_resample", [False, True])
 def test_resampling_warning_binary_image(affine_eye, rng, force_resample):
     # Resampling a binary image with continuous or
@@ -481,6 +482,7 @@ def test_resample_img_copied_header(img_4d_mni_tr2, force_resample):
     )
 
 
+@pytest.mark.thread_unsafe
 @pytest.mark.parametrize("force_resample", [False, True])
 def test_4d_affine_bounding_box_error(affine_eye, force_resample):
     bigger_data = np.zeros([10, 10, 10])
@@ -639,6 +641,7 @@ def test_raises_bbox_error_if_data_outside_box(affine_eye, force_resample):
             )
 
 
+@pytest.mark.thread_unsafe
 @pytest.mark.parametrize("force_resample", [False, True])
 @pytest.mark.parametrize(
     "axis_permutation", [[0, 1, 2], [1, 0, 2], [2, 1, 0], [0, 2, 1]]
@@ -792,6 +795,7 @@ def test_crop(affine_eye):
     assert_equal(get_data(cropped), data)
 
 
+@pytest.mark.thread_unsafe
 @pytest.mark.parametrize("force_resample", [False, True])
 def test_resample_identify_affine_int_translation(
     affine_eye, rng, force_resample
@@ -1046,6 +1050,7 @@ def test_reorder_img_copied_header(img_4d_mni_tr2):
     )
 
 
+@pytest.mark.thread_unsafe
 def test_coord_transform_trivial(affine_eye, rng):
     sform = affine_eye
     x = rng.random((10,))
@@ -1150,7 +1155,6 @@ def test_resampling_with_int_types_no_crash(affine_eye, dtype, force_resample):
 
 @pytest.mark.parametrize("force_resample", [False, True])
 @pytest.mark.parametrize("dtype", ["int64", "uint64", "<i8", ">i8"])
-@pytest.mark.parametrize("no_int64_nifti", ["allow for this test"])
 def test_resampling_with_int64_types_no_crash(
     affine_eye, dtype, force_resample
 ):
