@@ -167,7 +167,7 @@ def _generate_confounds_file_candidates(nii_file, flag_tedana=False):
     ----------
     nii_file : str
         Path to the functional image file.
-    flag_tedana : bool, optional
+    flag_tedana : bool, default=False
         If True, also generate candidates with desc=ICA for TEDANA
         optimally combined output. Defaults to False.
 
@@ -239,7 +239,7 @@ def _get_file_name(nii_file, flag_tedana=False):
     nii_file : str
         Path to the functional image file.
 
-    flag_tedana : bool, optional
+    flag_tedana : bool, default=False
         If True, look for TEDANA confounds files. Defaults to False.
 
     Returns
@@ -362,14 +362,14 @@ def load_confounds_json(confounds_json, flag_acompcor):
     try:
         with Path(confounds_json).open("rb") as f:
             confounds_json = json.load(f)
-    except OSError:
+    except OSError as e:
         if flag_acompcor:
             raise ValueError(
                 f"Could not find associated json file {confounds_json}."
                 "This is necessary for anatomical CompCor."
                 "The CompCor component is only supported for fMRIprep "
                 "version >= 1.4.0."
-            )
+            ) from e
     return confounds_json
 
 
@@ -481,7 +481,7 @@ def _ext_validator(image_file, ext):
     return valid_img, error_message
 
 
-def _check_images(image_file, flag_full_aroma, flag_tedana):
+def _check_images(image_file, flag_full_aroma, flag_tedana: bool) -> None:
     """Validate input file and ICA AROMA related file.
 
     Parameters
