@@ -17,7 +17,6 @@ from nilearn._utils.logger import find_stack_level
 from nilearn._utils.niimg import safe_get_data
 from nilearn._utils.param_validation import (
     check_parameter_in_allowed,
-    check_params,
     check_reduction_strategy,
 )
 from nilearn.image import (
@@ -65,7 +64,6 @@ class _ExtractionFunctor:
             strategy=self.strategy,
             keep_masked_labels=self.keep_masked_labels,
             mask_img=self.mask_img,
-            return_masked_atlas=True,
         )
         return signals, (labels, masked_labels_img)
 
@@ -91,7 +89,7 @@ class NiftiLabelsMasker(_LabelMaskerMixin, BaseMasker):
         See :ref:`extracting_data`.
         Region definitions, as one image of labels.
 
-    labels : :obj:`list` of :obj:`str`, optional
+    labels : :obj:`list` of :obj:`str`, or None, default=None
         Full labels corresponding to the labels image.
         This is used to improve reporting quality if provided.
         Mutually exclusive with ``lut``.
@@ -118,7 +116,7 @@ class NiftiLabelsMasker(_LabelMaskerMixin, BaseMasker):
 
             This value must be consistent with label values and image provided.
 
-    mask_img : Niimg-like object, optional
+    mask_img : Niimg-like object or None, default=None
         See :ref:`extracting_data`.
         Mask to apply to regions before extracting signals.
 
@@ -468,21 +466,7 @@ class NiftiLabelsMasker(_LabelMaskerMixin, BaseMasker):
 
         return display
 
-    @fill_doc
-    def fit(self, imgs=None, y=None):
-        """Prepare signal extraction from regions.
-
-        Parameters
-        ----------
-        imgs : :obj:`list` of Niimg-like objects or None, default=None
-            See :ref:`extracting_data`.
-            Image data passed to the reporter.
-
-        %(y_dummy)s
-        """
-        del y
-        check_params(self.__dict__)
-
+    def _fit(self, imgs):
         check_reduction_strategy(self.strategy)
         check_parameter_in_allowed(
             self.resampling_target,
@@ -490,14 +474,6 @@ class NiftiLabelsMasker(_LabelMaskerMixin, BaseMasker):
             "resampling_target",
         )
 
-        # Reset warning message
-        # in case where the masker was previously fitted
-        self._report_content["warning_messages"] = []
-
-        self.clean_args_ = {} if self.clean_args is None else self.clean_args
-
-        self._fit_cache()
-
         mask_logger("load_regions", self.labels_img, verbose=self.verbose)
 
         self.labels_img_ = deepcopy(self.labels_img)
@@ -522,8 +498,6 @@ class NiftiLabelsMasker(_LabelMaskerMixin, BaseMasker):
         if imgs is not None:
             imgs_ = check_niimg(imgs, atleast_4d=True)
 
-        self.mask_img_ = self._load_mask(imgs)
-
         # Check shapes and affines for resample.
         if self.resampling_target is None:
             images = {"labels": self.labels_img_}
@@ -615,18 +589,7 @@ class NiftiLabelsMasker(_LabelMaskerMixin, BaseMasker):
             Images to process.
             If a 3D niimg is provided, a 1D array is returned.
 
-        y : None
-            This parameter is unused. It is solely included for scikit-learn
-            compatibility.
-
-        region_ids_: dict[str | int, int | float] = {}
-        if self.background_label in index:
-            index.pop(index.index(self.background_label))
-            region_ids_["background"] = self.background_label
-        for i, id in enumerate(index):
-            region_ids_[i] = id  # noqa : PERF403
-
-        return region_ids_
+        %(y_dummy)s
 
         %(confounds)s
 
@@ -644,7 +607,7 @@ class NiftiLabelsMasker(_LabelMaskerMixin, BaseMasker):
             imgs, confounds=confounds, sample_mask=sample_mask
         )
 
-    def __sklearn_is_fitted__(self):
+    def __sklearn_is_fitted__(self) -> bool:
         return hasattr(self, "labels_img_") and hasattr(self, "lut_")
 
     @fill_doc
