@@ -14,7 +14,6 @@ from nilearn._utils.helpers import is_matplotlib_installed
 from nilearn._utils.logger import find_stack_level
 from nilearn._utils.param_validation import (
     check_parameter_in_allowed,
-    check_params,
 )
 from nilearn.image import (
     check_niimg,
@@ -80,7 +79,7 @@ class NiftiMapsMasker(ClassNamePrefixFeaturesOutMixin, BaseMasker):
         Set of continuous maps. One representative time course per map is
         extracted using least square regression.
 
-    mask_img : 3D niimg-like object, optional
+    mask_img : 3D niimg-like object or None, default=None
         See :ref:`extracting_data`.
         Mask to apply to regions before extracting signals.
 
@@ -373,31 +372,13 @@ class NiftiMapsMasker(ClassNamePrefixFeaturesOutMixin, BaseMasker):
 
         return embedded_images
 
-    @fill_doc
-    def fit(self, imgs=None, y=None):
-        """Prepare signal extraction from regions.
-
-        Parameters
-        ----------
-        imgs : :obj:`list` of Niimg-like objects or None, default=None
-            See :ref:`extracting_data`.
-            Image data passed to the reporter.
-
-        %(y_dummy)s
-        """
-        del y
-        check_params(self.__dict__)
-
+    def _fit(self, imgs=None):
         check_parameter_in_allowed(
             self.resampling_target,
             ("mask", "maps", "data", None),
             "resampling_target",
         )
 
-        # Reset warning message
-        # in case where the masker was previously fitted
-        self._report_content["warning_messages"] = []
-
         if self.mask_img is None and self.resampling_target == "mask":
             raise ValueError(
                 "resampling_target has been set to 'mask' but no mask "
@@ -405,8 +386,6 @@ class NiftiMapsMasker(ClassNamePrefixFeaturesOutMixin, BaseMasker):
                 "Set resampling_target to something else or provide a mask."
             )
 
-        self.clean_args_ = {} if self.clean_args is None else self.clean_args
-
         # Load images
         maps_img = self.maps_img
         if hasattr(self, "_maps_img"):
@@ -414,8 +393,6 @@ class NiftiMapsMasker(ClassNamePrefixFeaturesOutMixin, BaseMasker):
             # maps_img before passing to its parent fit method.
             maps_img = self._maps_img
 
-        self._fit_cache()
-
         mask_logger("load_regions", maps_img, verbose=self.verbose)
 
         self.maps_img_ = deepcopy(maps_img)
@@ -432,8 +409,6 @@ class NiftiMapsMasker(ClassNamePrefixFeaturesOutMixin, BaseMasker):
         if imgs is not None:
             imgs_ = check_niimg(imgs)
 
-        self.mask_img_ = self._load_mask(imgs)
-
         # Check shapes and affines for resample.
         if self.resampling_target is None:
             images = {"maps": self.maps_img_}
@@ -512,7 +487,7 @@ class NiftiMapsMasker(ClassNamePrefixFeaturesOutMixin, BaseMasker):
 
         return self
 
-    def __sklearn_is_fitted__(self):
+    def __sklearn_is_fitted__(self) -> bool:
         return hasattr(self, "maps_img_") and hasattr(self, "n_elements_")
 
     @fill_doc
