@@ -23,7 +23,7 @@ from nilearn._utils.estimator_checks import (
     nilearn_check_estimator,
     return_expected_failed_checks,
 )
-from nilearn._utils.tags import SKLEARN_LT_1_6
+from nilearn._utils.versions import SKLEARN_LT_1_6
 from nilearn.conftest import _img_labels
 from nilearn.image import get_data
 from nilearn.maskers import NiftiLabelsMasker, NiftiMasker
@@ -410,7 +410,7 @@ def test_nifti_labels_masker_resampling_to_labels(
     fmri11_img_r = masker.inverse_transform(signals)
 
     assert_almost_equal(fmri11_img_r.affine, masker.labels_img_.affine)
-    assert fmri11_img_r.shape == (masker.labels_img_.shape[:3] + (length,))
+    assert fmri11_img_r.shape == ((*masker.labels_img_.shape[:3], length))
 
 
 @pytest.mark.slow
@@ -464,7 +464,7 @@ def test_nifti_labels_masker_resampling_to_clipped_labels(
     fmri11_img_r = masker.inverse_transform(signals)
 
     assert_almost_equal(fmri11_img_r.affine, masker.labels_img_.affine)
-    assert fmri11_img_r.shape == (masker.labels_img_.shape[:3] + (length,))
+    assert fmri11_img_r.shape == ((*masker.labels_img_.shape[:3], length))
 
 
 def test_nifti_labels_masker_resampling_to_none(
