@@ -12,7 +12,7 @@ from nilearn._utils.estimator_checks import (
     return_expected_failed_checks,
 )
 from nilearn._utils.helpers import is_windows_platform
-from nilearn._utils.tags import SKLEARN_LT_1_6
+from nilearn._utils.versions import SKLEARN_LT_1_6
 from nilearn.image import get_data, new_img_like
 from nilearn.maskers import NiftiSpheresMasker
 
@@ -159,7 +159,7 @@ def test_errors():
         masker.fit()
 
 
-def test_nifti_spheres_masker_overlap(rng, affine_eye):
+def test_overlap(rng, affine_eye):
     """Throw error when allow_overlap=False and some spheres overlap."""
     shape = (5, 5, 5)
 
@@ -262,7 +262,8 @@ def test_is_nifti_spheres_masker_give_nans(rng, affine_eye):
     assert not np.isnan(np.sum(masker.fit_transform(img)))
 
 
-def test_nifti_spheres_masker_inverse_transform(rng, affine_eye):
+@pytest.mark.slow
+def test_inverse_transform(rng, affine_eye):
     """Applying the sphere_extraction example from above backwards."""
     data = rng.random((3, 3, 3, 5))
 
@@ -309,7 +310,7 @@ def test_nifti_spheres_masker_inverse_transform(rng, affine_eye):
     assert_array_equal(inverse_map.shape[:3], mask_img.shape)
 
 
-def test_nifti_spheres_masker_inverse_overlap(rng, affine_eye):
+def test_inverse_overlap(rng, affine_eye):
     """Throw error when data to inverse_transform has overlapping data and \
         allow_overlap=False.
     """
