@@ -9,7 +9,7 @@ from nilearn._utils.estimator_checks import (
     nilearn_check_estimator,
     return_expected_failed_checks,
 )
-from nilearn._utils.tags import SKLEARN_LT_1_6
+from nilearn._utils.versions import SKLEARN_LT_1_6
 from nilearn.maskers import SurfaceLabelsMasker
 from nilearn.maskers.tests.conftest import sklearn_surf_label_img
 from nilearn.surface import SurfaceImage
@@ -56,7 +56,7 @@ def test_check_estimator_nilearn(estimator, check, name):  # noqa: ARG001
     check(estimator)
 
 
-def test_surface_label_masker_fit(surf_label_img):
+def test_fit(surf_label_img):
     """Test fit and check estimated attributes."""
     masker = SurfaceLabelsMasker(labels_img=surf_label_img)
     masker = masker.fit()
@@ -69,7 +69,7 @@ def test_surface_label_masker_fit(surf_label_img):
     assert masker.region_ids_ == {"background": 0, 0: 1}
 
 
-def test_surface_label_masker_fit_transform(surf_label_img, surf_img_1d):
+def test_fit_transform(surf_label_img, surf_img_1d):
     """Test transform does not return any value for the background.
 
     A single scalar should be return as the mask only has 1 region.
@@ -82,7 +82,7 @@ def test_surface_label_masker_fit_transform(surf_label_img, surf_img_1d):
 
 
 @pytest.mark.parametrize("labels", [["Background", "bar"], ["bar"]])
-def test_surface_label_masker_fit_with_labels(surf_label_img, labels):
+def test_fit_with_labels(surf_label_img, labels):
     """Check passing labels is reflected in attributes.
 
     Should behave the same even if "Background" is not in the list of labels
@@ -99,7 +99,7 @@ def test_surface_label_masker_fit_with_labels(surf_label_img, labels):
 
 
 @pytest.mark.parametrize("labels", [["bar"], ["bar", "Background"]])
-def test_surface_label_masker_fit_background_label(surf_label_img, labels):
+def test_fit_background_label(surf_label_img, labels):
     """Check that labels and background label can be matched properly.
 
     Here we say that the background label is 1 and not 0.
@@ -119,7 +119,7 @@ def test_surface_label_masker_fit_background_label(surf_label_img, labels):
     assert masker.region_ids_ == {"background": 1, 0: 0}
 
 
-def test_surface_label_masker_fit_too_many_labels(surf_label_img):
+def test_fit_too_many_labels(surf_label_img):
     """Check passing labels is reflected in attributes.
 
     Check warning are thrown when too many are passed.
@@ -138,7 +138,7 @@ def test_surface_label_masker_fit_too_many_labels(surf_label_img):
     assert masker.region_ids_ == {"background": 0, 0: 1}
 
 
-def test_surface_label_masker_fit_too_few_labels(surf_label_img):
+def test_fit_too_few_labels(surf_label_img):
     """Check passing labels is reflected in attributes.
 
     Check warning are thrown when too few are passed.
@@ -157,7 +157,7 @@ def test_surface_label_masker_fit_too_few_labels(surf_label_img):
     assert masker.region_ids_ == {"background": 0, 0: 1}
 
 
-def test_surface_label_masker_fit_with_lut(surf_label_img, tmp_path):
+def test_fit_with_lut(surf_label_img, tmp_path):
     """Check passing lut is reflected in attributes.
 
     Check that lut can be read from:
@@ -183,6 +183,7 @@ def test_surface_label_masker_fit_with_lut(surf_label_img, tmp_path):
         assert masker.lut_["name"].to_list() == ["Background", "bar"]
 
 
+@pytest.mark.thread_unsafe
 @pytest.mark.parametrize(
     "background_label, n_expected_regions", [(0, 3), (1, 2)]
 )
@@ -249,7 +250,7 @@ def test_label_image_no_background_missing_regions(
         assert len(labels_masker.region_ids_) == n_expected_regions
 
 
-def test_surface_label_masker_error_names_and_lut(surf_label_img):
+def test_error_names_and_lut(surf_label_img):
     """Cannot pass both look up table AND names."""
     lut = pd.DataFrame({"index": [0, 1], "name": ["background", "bar"]})
     masker = SurfaceLabelsMasker(
@@ -262,13 +263,14 @@ def test_surface_label_masker_error_names_and_lut(surf_label_img):
         masker.fit()
 
 
-def test_surface_label_masker_fit_no_report(surf_label_img):
+def test_fit_no_report(surf_label_img):
     """Check no report data is stored."""
     masker = SurfaceLabelsMasker(labels_img=surf_label_img, reports=False)
     masker = masker.fit()
     assert masker._has_report_data() is False
 
 
+@pytest.mark.thread_unsafe
 @pytest.mark.parametrize(
     "strategy",
     (
@@ -281,7 +283,7 @@ def test_surface_label_masker_fit_no_report(surf_label_img):
         "maximum",
     ),
 )
-def test_surface_label_masker_transform(surf_label_img, surf_img_1d, strategy):
+def test_transform(surf_label_img, surf_img_1d, strategy):
     """Test transform extract signals.
 
     Also a smoke test for different strategies.
@@ -295,7 +297,7 @@ def test_surface_label_masker_transform(surf_label_img, surf_img_1d, strategy):
     assert signal.size == 1
 
 
-def test_surface_label_masker_transform_with_mask(surf_mesh, surf_img_2d):
+def test_transform_with_mask(surf_mesh, surf_img_2d):
     """Test transform extract signals with a mask and check warning."""
     # create a labels image
     labels_data = {
@@ -427,7 +429,7 @@ def inverse_data_right_1d_with_expected_mean(expected_mean_value):
     )
 
 
-def test_surface_label_masker_check_output_1d(
+def test_check_output_1d(
     surf_mesh,
     polydata_labels,
     expected_signal,
@@ -482,7 +484,7 @@ def test_surface_label_masker_check_output_1d(
     assert_array_equal(img.data.parts["right"], expected_inverse_data["right"])
 
 
-def test_surface_label_masker_lut_unsorted(
+def test_lut_unsorted(
     surf_mesh,
     polydata_labels,
     expected_signal,
@@ -534,7 +536,7 @@ def test_surface_label_masker_lut_unsorted(
     assert_array_equal(signal, np.asarray(expected_signal))
 
 
-def test_surface_label_masker_check_output_2d(
+def test_check_output_2d(
     surf_mesh,
     polydata_labels,
     expected_mean_value,
@@ -636,9 +638,7 @@ def test_surface_label_masker_check_output_2d(
     assert_array_equal(img.data.parts["right"], expected_inverse_data["right"])
 
 
-def test_surface_label_masker_inverse_transform_with_mask(
-    surf_mesh, surf_img_2d
-):
+def test_inverse_transform_with_mask(surf_mesh, surf_img_2d):
     """Test inverse_transform with mask: inverted image's shape, warning if
     mask removes labels and data corresponding to removed labels is zeros.
     """
@@ -678,7 +678,7 @@ def test_surface_label_masker_inverse_transform_with_mask(
     assert np.all(img_inverted.data.parts["right"][2:, :] == 0)
 
 
-def test_surface_label_masker_labels_img_none():
+def test_labels_img_none():
     """Test that an error is raised when labels_img is None."""
     with pytest.raises(
         ValueError,
