@@ -13,6 +13,7 @@ from matplotlib.colors import (
     Normalize,
 )
 
+from nilearn._utils.docs import fill_doc
 from nilearn._utils.extmath import fast_abs_percentile
 from nilearn._utils.logger import find_stack_level
 from nilearn._utils.param_validation import check_threshold
@@ -25,6 +26,7 @@ from nilearn.plotting._utils import (
 )
 
 
+@fill_doc
 def threshold_cmap(
     cmap, norm, threshold, threshold_color=(0.5, 0.5, 0.5, 1.0)
 ):
@@ -134,11 +136,14 @@ def create_colormap_from_lut(cmap, default_cmap="gist_ncar"):
         return default_cmap
 
     # Ensure colors are properly extracted from DataFrame
-    colors = cmap.sort_values(by="index")["color"].tolist()
+    cmap = cmap.sort_values(by="index")
+    cmap = cmap[cmap["name"] != "background"]
+    cmap = cmap[cmap["name"] != "Background"]
+    color = cmap["color"].tolist()
 
     # Create a colormap from the list of colors
     return LinearSegmentedColormap.from_list(
-        "custom_colormap", colors, N=len(colors)
+        "custom_colormap", color, N=len(color) + 1
     )
 
 
