@@ -8,6 +8,7 @@ from scipy.sparse import issparse
 from scipy.stats import scoreatpercentile
 
 from nilearn import DEFAULT_DIVERGING_CMAP
+from nilearn._utils.docs import fill_doc
 from nilearn._utils.logger import find_stack_level
 from nilearn._utils.param_validation import check_threshold
 from nilearn.plotting.displays._axes import GlassBrainAxes
@@ -15,12 +16,12 @@ from nilearn.plotting.displays._slicers import OrthoSlicer
 from nilearn.plotting.displays._utils import get_create_display_fun
 
 
+@fill_doc
 class OrthoProjector(OrthoSlicer):
     """A class to create linked axes for plotting orthogonal projections \
     of 3D maps.
 
-    This visualization mode can be activated from
-    :func:`~nilearn.plotting.plot_glass_brain`, by setting
+    This visualization mode can be activated by setting
     ``display_mode='ortho'``:
 
     .. code-block:: python
@@ -32,14 +33,17 @@ class OrthoProjector(OrthoSlicer):
         # display is an instance of the OrthoProjector class
         display = plot_glass_brain(img, display_mode="ortho")
 
+    %(projector_init_parameters)s
+
     Attributes
     ----------
+    cut_coords : (None, None, None)
+        The world coordinates of the point where the cut is performed.
+
     axes : :obj:`dict` of :class:`~nilearn.plotting.displays.GlassBrainAxes`
-        The 3 axes used to plot each view ('x', 'y', and 'z').
-
-    frame_axes : :class:`~matplotlib.axes.Axes`
-        The axes framing the whole set of views.
+        The axes used for plotting in each direction ('x', 'y' and 'z' here).
 
+    %(displays_partial_attributes)s
     """
 
     _axes_class = GlassBrainAxes  # type: ignore[assignment]
@@ -51,14 +55,50 @@ class OrthoProjector(OrthoSlicer):
         threshold=None,  # noqa: ARG003
         cut_coords=None,  # noqa: ARG003
     ):
-        """Find the coordinates of the cut."""
+        """Return a tuple of None of length corresponding to the number of
+        directions of this projector.
+
+        Specified parameters are not used.
+
+        Parameters
+        ----------
+        img : 3D :class:`~nibabel.nifti1.Nifti1Image`, default=None
+            The brain image.
+
+        threshold : :obj:`int` or :obj:`float` or None, default=None
+            Threshold to apply.
+
+        cut_coords : sequence of :obj:`float` or :obj:`int`, or None, \
+                     default=None
+            The world coordinates of the point where the cut is performed.
+
+        Returns
+        -------
+        cut_coords : :obj:`tuple` of `None`
+            tuple of None of length corresponding to the number of
+            directions of this projector.
+
+        """
         return (None,) * len(cls._cut_displayed)
 
-    def draw_cross(self, cut_coords=None, **kwargs):
-        """Do nothing.
+    def draw_cross(self, cut_coords=None, **kwargs) -> None:
+        """Draw a crossbar on the plot to show where the cut is performed.
+
+        Not implemented for this projector.
 
         It does not make sense to draw crosses for the position of
         the cuts since we are taking the max along one axis.
+
+        Parameters
+        ----------
+        cut_coords : sequence of :obj:`float` or :obj:`int`, or None, \
+                     default=None
+            The position of the cross to draw in world coordinates.
+
+        kwargs : :obj:`dict`
+            Extra keyword arguments are passed to function
+            :func:`~matplotlib.pyplot.axhline`.
+
         """
 
     def _check_inputs_add_graph(
@@ -126,6 +166,7 @@ class OrthoProjector(OrthoSlicer):
                 f"'node_coords' shape is {node_coords_shape}."
             )
 
+    @fill_doc
     def add_graph(
         self,
         adjacency_matrix,
@@ -139,7 +180,7 @@ class OrthoProjector(OrthoSlicer):
         edge_kwargs=None,
         node_kwargs=None,
         colorbar=False,
-    ):
+    ) -> None:
         """Plot undirected graph on each of the axes.
 
         Parameters
@@ -162,28 +203,32 @@ class OrthoProjector(OrthoSlicer):
         edge_cmap : :class:`~matplotlib.colors.Colormap`, default="RdBu_r"
             Colormap used for representing the strength of the edges.
 
-        edge_vmin, edge_vmax : :obj:`float`, optional
+        edge_vmin, edge_vmax : :obj:`float` or None, default=None
             - If not ``None``, either or both of these values will be used
               to as the minimum and maximum values to color edges.
             - If ``None`` are supplied, the maximum absolute value within the
               given threshold will be used as minimum (multiplied by -1) and
               maximum coloring levels.
 
-        edge_threshold : :obj:`str` or :obj:`int` or :obj:`float`, optional
+        edge_threshold : :obj:`str` or :obj:`int` or :obj:`float` \
+              or None, default=None
             - If it is a number only the edges with a value greater than
               ``edge_threshold`` will be shown.
             - If it is a string it must finish with a percent sign,
-              e.g. "25.3%", and only the edges with a abs(value) above
+              e.g. "25.3%%", and only the edges with a abs(value) above
               the given percentile will be shown.
 
-        edge_kwargs : :obj:`dict`, optional
+        edge_kwargs : :obj:`dict`, default=None
             Will be passed as kwargs for each edge
             :class:`~matplotlib.lines.Line2D`.
 
-        node_kwargs : :obj:`dict`
+        node_kwargs : :obj:`dict`, default=None
             Will be passed as kwargs to the function
             :func:`~matplotlib.pyplot.scatter` which plots all the
             nodes at one.
+
+        %(colorbar)s
+            Default=False.
         """
         # set defaults
         edge_kwargs = edge_kwargs or {}
@@ -291,9 +336,10 @@ class OrthoProjector(OrthoSlicer):
         plt.draw_if_interactive()
 
 
+@fill_doc
 class XProjector(OrthoProjector):
     """The ``XProjector`` class enables sagittal visualization through 2D \
-    projections with :func:`~nilearn.plotting.plot_glass_brain`.
+    projections.
 
     This visualization mode can be activated by setting ``display_mode='x'``:
 
@@ -306,13 +352,17 @@ class XProjector(OrthoProjector):
         # display is an instance of the XProjector class
         display = plot_glass_brain(img, display_mode="x")
 
+    %(projector_init_parameters)s
+
     Attributes
     ----------
-    axes : :obj:`dict` of :class:`~nilearn.plotting.displays.GlassBrainAxes`
-           The axes used for plotting.
+    cut_coords : (None,)
+        The world coordinates of the point where the cut is performed.
 
-    frame_axes : :class:`~matplotlib.axes.Axes`
-                 The axes framing the whole set of views.
+    axes : :obj:`dict` of :class:`~nilearn.plotting.displays.GlassBrainAxes`
+        The axes used for plotting in each direction ('x' here).
+
+    %(displays_partial_attributes)s
 
     See Also
     --------
@@ -325,9 +375,10 @@ class XProjector(OrthoProjector):
     _default_figsize: ClassVar[list[float]] = [2.6, 3.0]
 
 
+@fill_doc
 class YProjector(OrthoProjector):
     """The ``YProjector`` class enables coronal visualization through 2D \
-    projections with :func:`~nilearn.plotting.plot_glass_brain`.
+    projections.
 
     This visualization mode can be activated by setting ``display_mode='y'``:
 
@@ -340,13 +391,17 @@ class YProjector(OrthoProjector):
         # display is an instance of the YProjector class
         display = plot_glass_brain(img, display_mode="y")
 
+    %(projector_init_parameters)s
+
     Attributes
     ----------
-    axes : :obj:`dict` of :class:`~nilearn.plotting.displays.GlassBrainAxes`
-        The axes used for plotting.
+    cut_coords : (None,)
+        The world coordinates of the point where the cut is performed.
 
-    frame_axes : :class:`~matplotlib.axes.Axes`
-        The axes framing the whole set of views.
+    axes : :obj:`dict` of :class:`~nilearn.plotting.displays.GlassBrainAxes`
+        The axes used for plotting in each direction ('y' here).
+
+    %(displays_partial_attributes)s
 
     See Also
     --------
@@ -359,9 +414,10 @@ class YProjector(OrthoProjector):
     _default_figsize: ClassVar[list[float]] = [2.2, 3.0]
 
 
+@fill_doc
 class ZProjector(OrthoProjector):
     """The ``ZProjector`` class enables axial visualization through 2D \
-    projections with :func:`~nilearn.plotting.plot_glass_brain`.
+    projections.
 
     This visualization mode can be activated by setting ``display_mode='z'``:
 
@@ -374,13 +430,17 @@ class ZProjector(OrthoProjector):
         # display is an instance of the ZProjector class
         display = plot_glass_brain(img, display_mode="z")
 
+    %(projector_init_parameters)s
+
     Attributes
     ----------
-    axes : :obj:`dict` of :class:`~nilearn.plotting.displays.GlassBrainAxes`
-        The axes used for plotting.
+    cut_coords : (None,)
+        The world coordinates of the point where the cut is performed.
 
-    frame_axes : :class:`~matplotlib.axes.Axes`
-        The axes framing the whole set of views.
+    axes : :obj:`dict` of :class:`~nilearn.plotting.displays.GlassBrainAxes`
+        The axes used for plotting in each direction ('z' here).
+
+    %(displays_partial_attributes)s
 
     See Also
     --------
@@ -393,14 +453,12 @@ class ZProjector(OrthoProjector):
     _default_figsize: ClassVar[list[float]] = [2.2, 3.4]
 
 
+@fill_doc
 class XZProjector(OrthoProjector):
     """The ``XZProjector`` class enables to combine sagittal \
-    and axial views \
-    on the same figure through 2D projections with \
-    :func:`~nilearn.plotting.plot_glass_brain`.
+    and axial views on the same figure through 2D projections.
 
-    This visualization mode
-    can be activated by setting ``display_mode='xz'``:
+    This visualization mode can be activated by setting ``display_mode='xz'``:
 
     .. code-block:: python
 
@@ -411,13 +469,17 @@ class XZProjector(OrthoProjector):
         # display is an instance of the XZProjector class
         display = plot_glass_brain(img, display_mode="xz")
 
+    %(projector_init_parameters)s
+
     Attributes
     ----------
+    cut_coords : (None, None)
+        The world coordinates of the point where the cut is performed.
+
     axes : :obj:`dict` of :class:`~nilearn.plotting.displays.GlassBrainAxes`
         The axes used for plotting in each direction ('x' and 'z' here).
 
-    frame_axes : :class:`~matplotlib.axes.Axes`
-        The axes framing the whole set of views.
+    %(displays_partial_attributes)s
 
     See Also
     --------
@@ -429,11 +491,10 @@ class XZProjector(OrthoProjector):
     _cut_displayed = "xz"
 
 
+@fill_doc
 class YXProjector(OrthoProjector):
     """The ``YXProjector`` class enables to combine coronal \
-    and sagittal views \
-    on the same figure through 2D projections with \
-    :func:`~nilearn.plotting.plot_glass_brain`.
+    and sagittal views on the same figure through 2D projections.
 
     This visualization mode
     can be activated by setting ``display_mode='yx'``:
@@ -447,13 +508,17 @@ class YXProjector(OrthoProjector):
         # display is an instance of the YXProjector class
         display = plot_glass_brain(img, display_mode="yx")
 
+    %(projector_init_parameters)s
+
     Attributes
     ----------
-    axes : :obj:`dict` of :class:`~nilearn.plotting.displays.GlassBrainAxes`
-        The axes used for plotting in each direction ('x' and 'y' here).
+    cut_coords : (None, None)
+        The world coordinates of the point where the cut is performed.
 
-    frame_axes : :class:`~matplotlib.axes.Axes`
-        The axes framing the whole set of views.
+    axes : :obj:`dict` of :class:`~nilearn.plotting.displays.GlassBrainAxes`
+        The axes used for plotting in each direction ('y' and 'x' here).
+
+    %(displays_partial_attributes)s
 
     See Also
     --------
@@ -462,16 +527,15 @@ class YXProjector(OrthoProjector):
 
     """
 
-    _cut_displayed = "yx"
+    _cut_displayed = "xy"
 
 
+@fill_doc
 class YZProjector(OrthoProjector):
     """The ``YZProjector`` class enables to combine coronal and axial views \
-    on the same figure through 2D projections with \
-    :func:`~nilearn.plotting.plot_glass_brain`.
+    on the same figure through 2D projections.
 
-    This visualization mode
-    can be activated by setting ``display_mode='yz'``:
+    This visualization mode can be activated by setting ``display_mode='yz'``:
 
     .. code-block:: python
 
@@ -482,13 +546,17 @@ class YZProjector(OrthoProjector):
         # display is an instance of the YZProjector class
         display = plot_glass_brain(img, display_mode="yz")
 
+    %(projector_init_parameters)s
+
     Attributes
     ----------
+    cut_coords : (None, None)
+        The world coordinates of the point where the cut is performed.
+
     axes : :obj:`dict` of :class:`~nilearn.plotting.displays.GlassBrainAxes`
         The axes used for plotting in each direction ('y' and 'z' here).
 
-    frame_axes : :class:`~matplotlib.axes.Axes`
-        The axes framing the whole set of views.
+    %(displays_partial_attributes)s
 
     See Also
     --------
@@ -501,10 +569,10 @@ class YZProjector(OrthoProjector):
     _default_figsize: ClassVar[list[float]] = [2.2, 3.4]
 
 
+@fill_doc
 class LYRZProjector(OrthoProjector):
-    """The ``LYRZProjector`` class enables ? visualization \
-    on the same figure through 2D projections with \
-    :func:`~nilearn.plotting.plot_glass_brain`.
+    """The ``LYRZProjector`` class enables visualization \
+    on the same figure through 2D projections.
 
     This visualization mode
     can be activated by setting ``display_mode='lyrz'``:
@@ -518,14 +586,18 @@ class LYRZProjector(OrthoProjector):
         # display is an instance of the LYRZProjector class
         display = plot_glass_brain(img, display_mode="lyrz")
 
+    %(projector_init_parameters)s
+
     Attributes
     ----------
-    axes : :obj:`dict` of :class:`~nilearn.plotting.displays.GlassBrainAxes`
-        The axes used for plotting in each direction ('l', 'y', 'r',
-        and 'z' here).
+    cut_coords : (None, None, None, None)
+        The world coordinates of the point where the cut is performed.
 
-    frame_axes : :class:`~matplotlib.axes.Axes`
-        The axes framing the whole set of views.
+    axes : :obj:`dict` of :class:`~nilearn.plotting.displays.GlassBrainAxes`
+        The axes used for plotting in each direction ('l', 'y', 'r' and 'z'
+        here).
+
+    %(displays_partial_attributes)s
 
     See Also
     --------
@@ -536,10 +608,10 @@ class LYRZProjector(OrthoProjector):
     _cut_displayed = "lyrz"
 
 
+@fill_doc
 class LZRYProjector(OrthoProjector):
-    """The ``LZRYProjector`` class enables ? visualization \
-    on the same figure through 2D projections with \
-    :func:`~nilearn.plotting.plot_glass_brain`.
+    """The ``LZRYProjector`` class enables visualization \
+    on the same figure through 2D projections.
 
     This visualization mode
     can be activated by setting ``display_mode='lzry'``:
@@ -553,14 +625,18 @@ class LZRYProjector(OrthoProjector):
         # display is an instance of the LZRYProjector class
         display = plot_glass_brain(img, display_mode="lzry")
 
+    %(projector_init_parameters)s
+
     Attributes
     ----------
-    axes : :obj:`dict` of :class:`~nilearn.plotting.displays.GlassBrainAxes`
-        The axes used for plotting in each direction ('l', 'z', 'r',
-        and 'y' here).
+    cut_coords : (None, None, None, None)
+        The world coordinates of the point where the cut is performed.
 
-    frame_axes : :class:`~matplotlib.axes.Axes`
-        The axes framing the whole set of views.
+    axes : :obj:`dict` of :class:`~nilearn.plotting.displays.GlassBrainAxes`
+        The axes used for plotting in each direction ('l', 'z', 'r' and 'y'
+        here).
+
+    %(displays_partial_attributes)s
 
     See Also
     --------
@@ -571,13 +647,12 @@ class LZRYProjector(OrthoProjector):
     _cut_displayed = "lzry"
 
 
+@fill_doc
 class LZRProjector(OrthoProjector):
     """The ``LZRProjector`` class enables hemispheric sagittal visualization \
-    on the same figure through 2D projections with \
-    :func:`~nilearn.plotting.plot_glass_brain`.
+    on the same figure through 2D projections.
 
-    This visualization mode
-    can be activated by setting ``display_mode='lzr'``:
+    This visualization mode can be activated by setting ``display_mode='lzr'``:
 
     .. code-block:: python
 
@@ -588,13 +663,17 @@ class LZRProjector(OrthoProjector):
         # display is an instance of the LZRProjector class
         display = plot_glass_brain(img, display_mode="lzr")
 
+    %(projector_init_parameters)s
+
     Attributes
     ----------
+    cut_coords : (None, None, None)
+        The world coordinates of the point where the cut is performed.
+
     axes : :obj:`dict` of :class:`~nilearn.plotting.displays.GlassBrainAxes`
         The axes used for plotting in each direction ('l', 'z' and 'r' here).
 
-    frame_axes : :class:`~matplotlib.axes.Axes`
-        The axes framing the whole set of views.
+    %(displays_partial_attributes)s
 
     See Also
     --------
@@ -605,13 +684,12 @@ class LZRProjector(OrthoProjector):
     _cut_displayed = "lzr"
 
 
+@fill_doc
 class LYRProjector(OrthoProjector):
-    """The ``LYRProjector`` class enables ? visualization \
-    on the same figure through 2D projections with \
-    :func:`~nilearn.plotting.plot_glass_brain`.
+    """The ``LYRProjector`` class enables visualization \
+    on the same figure through 2D projections.
 
-    This visualization mode
-    can be activated by setting ``display_mode='lyr'``:
+    This visualization mode can be activated by setting ``display_mode='lyr'``:
 
     .. code-block:: python
 
@@ -622,13 +700,17 @@ class LYRProjector(OrthoProjector):
         # display is an instance of the LYRProjector class
         display = plot_glass_brain(img, display_mode="lyr")
 
+    %(projector_init_parameters)s
+
     Attributes
     ----------
+    cut_coords : (None, None, None)
+        The world coordinates of the point where the cut is performed.
+
     axes : :obj:`dict` of :class:`~nilearn.plotting.displays.GlassBrainAxes`
         The axes used for plotting in each direction ('l', 'y' and 'r' here).
 
-    frame_axes : :class:`~matplotlib.axes.Axes`
-        The axes framing the whole set of views.
+    %(displays_partial_attributes)s
 
     See Also
     --------
@@ -639,13 +721,12 @@ class LYRProjector(OrthoProjector):
     _cut_displayed = "lyr"
 
 
+@fill_doc
 class LRProjector(OrthoProjector):
     """The ``LRProjector`` class enables left-right visualization \
-    on the same figure through 2D projections with \
-    :func:`~nilearn.plotting.plot_glass_brain`.
+    on the same figure through 2D projections.
 
-    This visualization mode
-    can be activated by setting ``display_mode='lr'``:
+    This visualization mode can be activated by setting ``display_mode='lr'``:
 
     .. code-block:: python
 
@@ -656,25 +737,29 @@ class LRProjector(OrthoProjector):
         # display is an instance of the LRProjector class
         display = plot_glass_brain(img, display_mode="lr")
 
+    %(projector_init_parameters)s
+
     Attributes
     ----------
-    axes : :obj:`dict` of :class:`~nilearn.plotting.displays.GlassBrainAxes`
-        The axes used for plotting in each direction ('l', and 'r' here).
+    cut_coords : (None, None)
+        The world coordinates of the point where the cut is performed.
 
-    frame_axes : :class:`~matplotlib.axes.Axes`
-        The axes framing the whole set of views.
+    axes : :obj:`dict` of :class:`~nilearn.plotting.displays.GlassBrainAxes`
+        The axes used for plotting in each direction ('l' and 'r' here).
+
+    %(displays_partial_attributes)s
 
     """
 
     _cut_displayed = "lr"
 
 
+@fill_doc
 class LProjector(OrthoProjector):
     """The ``LProjector`` class enables the visualization of left 2D \
-    projection with :func:`~nilearn.plotting.plot_glass_brain`.
+    projection.
 
-    This
-    visualization mode can be activated by setting ``display_mode='l'``:
+    This visualization mode can be activated by setting ``display_mode='l'``:
 
     .. code-block:: python
 
@@ -685,13 +770,17 @@ class LProjector(OrthoProjector):
         # display is an instance of the LProjector class
         display = plot_glass_brain(img, display_mode="l")
 
+    %(projector_init_parameters)s
+
     Attributes
     ----------
+    cut_coords : (None,)
+        The world coordinates of the point where the cut is performed.
+
     axes : :obj:`dict` of :class:`~nilearn.plotting.displays.GlassBrainAxes`
         The axes used for plotting in each direction ('l' here).
 
-    frame_axes : :class:`~matplotlib.axes.Axes`
-        The axes framing the whole set of views.
+    %(displays_partial_attributes)s
 
     See Also
     --------
@@ -703,9 +792,10 @@ class LProjector(OrthoProjector):
     _default_figsize: ClassVar[list[float]] = [2.6, 3.0]
 
 
+@fill_doc
 class RProjector(OrthoProjector):
     """The ``RProjector`` class enables the visualization of right 2D \
-    projection with :func:`~nilearn.plotting.plot_glass_brain`.
+    projection.
 
     This visualization mode can be activated by setting ``display_mode='r'``:
 
@@ -718,13 +808,17 @@ class RProjector(OrthoProjector):
         # display is an instance of the RProjector class
         display = plot_glass_brain(img, display_mode="r")
 
+    %(projector_init_parameters)s
+
     Attributes
     ----------
+    cut_coords : (None,)
+        The world coordinates of the point where the cut is performed.
+
     axes : :obj:`dict` of :class:`~nilearn.plotting.displays.GlassBrainAxes`
         The axes used for plotting in each direction ('r' here).
 
-    frame_axes : :class:`~matplotlib.axes.Axes`
-        The axes framing the whole set of views.
+    %(displays_partial_attributes)s
 
     See Also
     --------
