@@ -10,11 +10,17 @@ from nilearn._utils.extmath import fast_abs_percentile
 from nilearn._utils.logger import find_stack_level
 from nilearn._utils.ndimage import largest_connected_component
 from nilearn._utils.niimg import safe_get_data
-from nilearn._utils.niimg_conversions import check_niimg_3d, check_niimg_4d
 from nilearn._utils.numpy_conversions import as_ndarray
+from nilearn._utils.param_validation import check_parameter_in_allowed
 
 # Local imports
-from nilearn.image import get_data, iter_img, reorder_img
+from nilearn.image import (
+    check_niimg_3d,
+    check_niimg_4d,
+    get_data,
+    iter_img,
+    reorder_img,
+)
 from nilearn.image.image import smooth_array
 from nilearn.image.resampling import coord_transform
 from nilearn.plotting._utils import check_threshold_not_negative
@@ -256,10 +262,7 @@ def find_cut_slices(img, direction="z", n_cuts=7, spacing="auto"):
 
     """
     # misc
-    if direction not in "xyz":
-        raise ValueError(
-            f"'direction' must be one of 'x', 'y', or 'z'. Got '{direction}'"
-        )
+    check_parameter_in_allowed(direction, ("x", "y", "z"), "direction")
     axis = "xyz".index(direction)
     img = check_niimg_3d(img)
     affine = img.affine
@@ -272,14 +275,14 @@ def find_cut_slices(img, direction="z", n_cuts=7, spacing="auto"):
         )
         # resample is set to avoid issues with an image having a non-diagonal
         # affine and rotation.
-        img = reorder_img(img, resample="nearest", copy_header=True)
+        img = reorder_img(img, resample="nearest")
         affine = img.affine
     # note: orig_data is a copy of img._data_cache thanks to np.abs
     orig_data = np.abs(safe_get_data(img))
     this_shape = orig_data.shape[axis]
 
     if not isinstance(n_cuts, numbers.Number):
-        raise ValueError(
+        raise TypeError(
             "The number of cuts (n_cuts) must be an integer "
             "greater than or equal to 1. "
             f"You provided a value of n_cuts={n_cuts}."
@@ -423,13 +426,12 @@ def find_parcellation_cut_coords(
 
     """
     # check label_hemisphere input
-    if label_hemisphere not in ["left", "right"]:
-        raise ValueError(
-            f"Invalid label_hemisphere name:{label_hemisphere}.\n"
-            "Should be one of these 'left' or 'right'."
-        )
+    check_parameter_in_allowed(
+        label_hemisphere, ["left", "right"], "label_hemisphere"
+    )
+
     # Grab data and affine
-    labels_img = reorder_img(check_niimg_3d(labels_img), copy_header=True)
+    labels_img = reorder_img(check_niimg_3d(labels_img))
     labels_data = get_data(labels_img)
     labels_affine = labels_img.affine
 
