@@ -373,6 +373,7 @@ def plot_surf_contours(
 
     nilearn.surface.vol_to_surf : For info on the generation of surfaces.
     """
+    check_params(locals())
     roi_map, surf_mesh, _ = check_surface_plotting_inputs(
         roi_map, surf_mesh, hemi, map_var_name="roi_map"
     )
@@ -844,7 +845,7 @@ def plot_surf_roi(
         correct view, `hemi` should have a value corresponding to `roi_map`
         data.
 
-        .. nilearn_versionchanged :: nilearn 0.13.0dev
+        .. nilearn_versionchanged :: nilearn 0.13.0
 
             Negative or non-integer values are no longer allowed.
 
