@@ -3,8 +3,8 @@ import re
 
 import numpy as np
 import pytest
-from lxml import etree
 
+from nilearn._utils.helpers import is_gil_enabled
 from nilearn.datasets import fetch_surf_fsaverage
 from nilearn.plotting.js_plotting_utils import (
     add_js_lib,
@@ -20,6 +20,7 @@ def _normalize_ws(text):
     return re.sub(r"\s+", " ", text)
 
 
+@pytest.mark.thread_unsafe
 def test_add_js_lib():
     """Tests for function add_js_lib.
 
@@ -113,6 +114,13 @@ def check_html_surface_plots(
     if title is not None:
         assert f"<title>{title}</title>" in str(html)
 
+    # when testing without the GIL
+    # we cannot import lxml as it requires the GIL
+    if not is_gil_enabled():
+        return
+
+    from lxml import etree
+
     root = etree.HTML(
         html.html.encode("utf-8"), parser=etree.HTMLParser(huge_tree=True)
     )
