@@ -16,13 +16,16 @@ from nilearn._utils.docs import fill_doc
 from nilearn._utils.logger import find_stack_level
 from nilearn._utils.niimg import safe_get_data
 from nilearn._utils.numpy_conversions import as_ndarray
-from nilearn._utils.param_validation import check_reduction_strategy
+from nilearn._utils.param_validation import (
+    check_params,
+    check_reduction_strategy,
+)
 from nilearn.image import check_niimg_3d, check_niimg_4d, new_img_like
 
 INF = 1000 * np.finfo(np.float32).eps
 
 
-def _check_shape_compatibility(img1, img2, dim=None):
+def _check_shape_compatibility(img1, img2, dim=None) -> None:
     """Check that shapes match for dimensions going from 0 to dim-1.
 
     Parameters
@@ -31,11 +34,11 @@ def _check_shape_compatibility(img1, img2, dim=None):
         See :ref:`extracting_data`.
         Image to extract the data from.
 
-    img2 : Niimg-like object, optional
+    img2 : Niimg-like object
         See :ref:`extracting_data`.
         Contains map or mask.
 
-    dim : :obj:`int`, optional
+    dim : :obj:`int`, default=None
         Integer slices a mask for a specific dimension.
 
     """
@@ -47,7 +50,7 @@ def _check_shape_compatibility(img1, img2, dim=None):
         raise ValueError("Images have incompatible shapes.")
 
 
-def _check_affine_equality(img1, img2):
+def _check_affine_equality(img1: Nifti1Image, img2: Nifti1Image) -> None:
     """Validate affines of 2 images.
 
     Parameters
@@ -56,7 +59,7 @@ def _check_affine_equality(img1, img2):
         See :ref:`extracting_data`.
         Image to extract the data from.
 
-    img2 : Niimg-like object, optional
+    img2 : Niimg-like object
         See :ref:`extracting_data`.
         Contains map or mask.
 
@@ -81,11 +84,11 @@ def _check_shape_and_affine_compatibility(img1, img2=None, dim=None):
         See :ref:`extracting_data`.
         Image to extract the data from.
 
-    img2 : Niimg-like object, optional
+    img2 : Niimg-like object, default=None
         See :ref:`extracting_data`.
         Contains map or mask.
 
-    dim : :obj:`int`, optional
+    dim : :obj:`int`, default=None
         Integer slices a mask for a specific dimension.
 
     Returns
@@ -131,7 +134,7 @@ def _get_labels_data(
         By default, the label zero is used to denote an absence of region.
         Use background_label to change it.
 
-    mask_img : Niimg-like object, optional
+    mask_img : Niimg-like object, default=None
         See :ref:`extracting_data`.
         Mask to apply to labels before extracting signals.
         Every point outside the mask is considered as background
@@ -140,7 +143,7 @@ def _get_labels_data(
     background_label : number, default=0
         Number representing background in labels_img.
 
-    dim : :obj:`int`, optional
+    dim : :obj:`int`, default=None
         Integer slices mask for a specific dimension.
 
     %(keep_masked_labels)s
@@ -221,7 +224,7 @@ def img_to_signals_labels(
     order="F",
     strategy="mean",
     keep_masked_labels=False,
-    return_masked_atlas=False,
+    return_masked_atlas=True,
 ):
     """Extract region signals from image.
 
@@ -256,16 +259,17 @@ def img_to_signals_labels(
 
     %(keep_masked_labels)s
 
-    return_masked_atlas : :obj:`bool`, default=False
+    return_masked_atlas : :obj:`bool`, default=True
         If True, the masked atlas is returned.
 
-        .. nilearn_versionchanged :: 0.13.0dev
+        .. nilearn_versionchanged :: 0.13.1
 
-            Default changed to False.
+            Default changed to True.
 
-        .. nilearn_deprecated:: 0.13.0dev
+        .. nilearn_deprecated:: 0.13.0
 
             This parameter will be removed in versions >= 0.15.0
+            and the masked atlas will always be returned.
 
     Returns
     -------
@@ -281,7 +285,6 @@ def img_to_signals_labels(
 
     masked_atlas : Niimg-like object
         Regions definition as labels after applying the mask.
-        returned if `return_masked_atlas` is True.
 
     See Also
     --------
@@ -291,6 +294,8 @@ def img_to_signals_labels(
         e.g. clusters
 
     """
+    check_params(locals())
+
     labels_img = check_niimg_3d(labels_img)
 
     check_reduction_strategy(strategy)
@@ -335,7 +340,9 @@ def img_to_signals_labels(
         warnings.warn(
             (
                 "In version 0.15, "
-                '"return_masked_atlas" parameter will be removed.'
+                '"return_masked_atlas" parameter will be removed '
+                "and the masked atlas will always be returned. "
+                'Set "return_masked_atlas" to True to avoid this warning.'
             ),
             FutureWarning,
             stacklevel=find_stack_level(),
@@ -473,6 +480,8 @@ def img_to_signals_maps(imgs, maps_img, mask_img=None, keep_masked_maps=False):
         maps e.g. ICA
 
     """
+    check_params(locals())
+
     maps_img = check_niimg_4d(maps_img)
     imgs = check_niimg_4d(imgs)
 
@@ -632,7 +641,7 @@ def _trim_maps(maps, mask, keep_empty=False, order="F"):
 
     n_regions = maps.shape[-1] if keep_empty else (sums > 0).sum()
     trimmed_maps = np.zeros(
-        maps.shape[:3] + (n_regions,), dtype=maps.dtype, order=order
+        (*maps.shape[:3], n_regions), dtype=maps.dtype, order=order
     )
     # use int8 instead of np.bool for Nifti1Image
     maps_mask = np.zeros(mask.shape, dtype=np.int8)
