@@ -156,6 +156,7 @@ def test_check_shape_and_affine_compatibility_error(
         _check_shape_and_affine_compatibility(img1=img_3d_zeros_eye, img2=img2)
 
 
+@pytest.mark.thread_unsafe
 def test_errors_3d(img_3d_zeros_eye, img_4d_zeros_eye):
     """Verify that 3D images are refused."""
     wrong_dim_image = img_3d_zeros_eye
@@ -169,6 +170,7 @@ def test_errors_3d(img_3d_zeros_eye, img_4d_zeros_eye):
         img_to_signals_maps(imgs=img_4d_zeros_eye, maps_img=wrong_dim_image)
 
 
+@pytest.mark.thread_unsafe
 def test_errors_4d_labels(img_4d_zeros_eye):
     """Verify that 4D images are refused."""
     wrong_dim_label_img = img_4d_zeros_eye
@@ -184,6 +186,7 @@ def test_errors_4d_labels(img_4d_zeros_eye):
         )
 
 
+@pytest.mark.thread_unsafe
 def test_errors_4d_masks(img_3d_zeros_eye, img_4d_zeros_eye):
     """Verify that 4D images are refused."""
     wrong_dim_mask_img = img_4d_zeros_eye
@@ -210,6 +213,7 @@ def test_errors_4d_masks(img_3d_zeros_eye, img_4d_zeros_eye):
         )
 
 
+@pytest.mark.thread_unsafe
 @pytest.mark.parametrize(
     "shape, affine, error_msg",
     [
@@ -226,6 +230,7 @@ def test_img_to_signals_labels_bad_labels_input(
         img_to_signals_labels(imgs=img_4d_zeros_eye, labels_img=bad_img)
 
 
+@pytest.mark.thread_unsafe
 @pytest.mark.parametrize(
     "shape, affine, error_msg",
     [
@@ -246,6 +251,7 @@ def test_img_to_signals_labels_bad_mask_input(
         )
 
 
+@pytest.mark.thread_unsafe
 def test_img_to_signals_labels_error_strategy(
     img_4d_zeros_eye, img_3d_zeros_eye
 ):
@@ -295,6 +301,7 @@ def test_signals_to_img_labels_bad_mask_input(
         )
 
 
+@pytest.mark.thread_unsafe
 @pytest.mark.parametrize(
     "shape, affine, error_msg",
     [
@@ -314,6 +321,7 @@ def test_img_to_signals_maps_bad_maps(
         )
 
 
+@pytest.mark.thread_unsafe
 @pytest.mark.parametrize(
     "shape, affine, error_msg",
     [
@@ -332,6 +340,7 @@ def test_img_to_signals_maps_bad_masks(
         )
 
 
+@pytest.mark.thread_unsafe
 def test_signals_extraction_with_labels_without_mask(
     signals, labels_data, labels_img, shape_3d_default, tmp_path
 ):
@@ -351,7 +360,7 @@ def test_signals_extraction_with_labels_without_mask(
     )
 
     # and back
-    signals_r, labels_r = img_to_signals_labels(
+    signals_r, labels_r, _ = img_to_signals_labels(
         imgs=data_img,
         labels_img=labels_img,
     )
@@ -360,7 +369,7 @@ def test_signals_extraction_with_labels_without_mask(
     assert labels_r == list(range(1, 9))
 
     filenames = write_imgs_to_path(data_img, file_path=tmp_path)
-    signals_r, labels_r = img_to_signals_labels(
+    signals_r, labels_r, _ = img_to_signals_labels(
         imgs=filenames, labels_img=labels_img
     )
 
@@ -368,6 +377,7 @@ def test_signals_extraction_with_labels_without_mask(
     assert labels_r == list(range(1, 9))
 
 
+@pytest.mark.thread_unsafe
 def test_signals_extraction_with_labels_without_mask_return_masked_atlas(
     signals, labels_img
 ):
@@ -398,6 +408,7 @@ def test_signals_extraction_with_labels_without_mask_return_masked_atlas(
     assert list(np.unique(labels_data_r)) == list(range(1, 9))
 
 
+@pytest.mark.thread_unsafe
 def test_signals_extraction_with_labels_with_mask(
     signals, labels_img, labels_data, mask_img, shape_3d_default, tmp_path
 ):
@@ -435,7 +446,7 @@ def test_signals_extraction_with_labels_with_mask(
     )
 
     # and back
-    signals_r, labels_r = img_to_signals_labels(
+    signals_r, labels_r, _ = img_to_signals_labels(
         imgs=data_img, labels_img=labels_img, mask_img=mask_img
     )
 
@@ -443,6 +454,7 @@ def test_signals_extraction_with_labels_with_mask(
     assert labels_r == list(range(1, 9))
 
 
+@pytest.mark.thread_unsafe
 def test_signals_extraction_with_labels_with_mask_return_masked_atlas(
     signals, labels_img, mask_img
 ):
@@ -478,6 +490,7 @@ def test_signals_extraction_with_labels_with_mask_return_masked_atlas(
 
 
 @pytest.mark.slow
+@pytest.mark.thread_unsafe
 def test_signal_extraction_with_maps(affine_eye, shape_3d_default, rng):
     # Generate signal imgs
     maps_img, mask_img = generate_maps(shape_3d_default, N_REGIONS)
@@ -506,6 +519,8 @@ def test_signal_extraction_with_maps(affine_eye, shape_3d_default, rng):
     assert_almost_equal(get_data(img_r), get_data(imgs))
 
 
+@pytest.mark.slow
+@pytest.mark.thread_unsafe
 def test_signal_extraction_with_maps_and_labels(
     labeled_regions, fmri_img, shape_3d_default
 ):
@@ -524,7 +539,7 @@ def test_signal_extraction_with_maps_and_labels(
     maps_signals, maps_labels = img_to_signals_maps(
         fmri_img, maps_img, keep_masked_maps=True
     )
-    labels_signals, labels_labels = img_to_signals_labels(
+    labels_signals, labels_labels, _ = img_to_signals_labels(
         imgs=fmri_img, labels_img=labeled_regions, keep_masked_labels=True
     )
     assert_almost_equal(maps_signals, labels_signals)
@@ -533,7 +548,7 @@ def test_signal_extraction_with_maps_and_labels(
     mask_img = _create_mask_with_3_regions_from_labels_data(
         labels_data, labeled_regions.affine
     )
-    labels_signals, labels_labels = img_to_signals_labels(
+    labels_signals, labels_labels, _ = img_to_signals_labels(
         imgs=fmri_img,
         labels_img=labeled_regions,
         mask_img=mask_img,
@@ -559,6 +574,7 @@ def test_signal_extraction_with_maps_and_labels(
     assert maps_img_r.shape == (*shape_3d_default, N_TIMEPOINTS)
 
 
+@pytest.mark.thread_unsafe
 def test_img_to_signals_labels_warnings(labeled_regions, fmri_img):
     labels_data = get_data(labeled_regions)
 
@@ -579,7 +595,7 @@ def test_img_to_signals_labels_warnings(labeled_regions, fmri_img):
         "4 labels "
         r"\(including background\).",
     ):
-        labels_signals, labels_labels = img_to_signals_labels(
+        labels_signals, labels_labels, _ = img_to_signals_labels(
             imgs=fmri_img,
             labels_img=labeled_regions,
             mask_img=mask_img,
@@ -599,7 +615,7 @@ def test_img_to_signals_labels_warnings(labeled_regions, fmri_img):
         FutureWarning,
         match='"keep_masked_labels" parameter will be removed.',
     ):
-        labels_signals, labels_labels = img_to_signals_labels(
+        labels_signals, labels_labels, _ = img_to_signals_labels(
             imgs=fmri_img,
             labels_img=labeled_regions,
             mask_img=mask_img,
@@ -627,6 +643,7 @@ def test_img_to_signals_labels_warnings(labeled_regions, fmri_img):
         )
 
 
+@pytest.mark.thread_unsafe
 def test_img_to_signals_maps_warnings(
     labeled_regions, fmri_img, shape_3d_default
 ):
@@ -684,6 +701,7 @@ def test_img_to_signals_maps_warnings(
     assert len(maps_labels) == 8
 
 
+@pytest.mark.thread_unsafe
 def test_signal_extraction_nans_in_regions_are_replaced_with_zeros():
     shape = (4, 5, 6)
     labels = list(range(N_REGIONS + 1))  # 0 is background
@@ -701,7 +719,7 @@ def test_signal_extraction_nans_in_regions_are_replaced_with_zeros():
     indices = tuple(ind[:1] for ind in np.where(region1))
     get_data(fmri_img)[indices] = np.nan
 
-    labels_signals, labels_labels = img_to_signals_labels(
+    labels_signals, labels_labels, _ = img_to_signals_labels(
         imgs=fmri_img, labels_img=labels_img, mask_img=mask_img
     )
 
@@ -745,7 +763,7 @@ def test_trim_maps(shape_3d_default):
 
     assert maps_i.flags["F_CONTIGUOUS"]
     assert len(maps_i_indices) == maps_i.shape[-1]
-    assert maps_i.shape == (maps_data.shape[:3] + (4,))
+    assert maps_i.shape == ((*maps_data.shape[:3], 4))
     maps_i_correct = maps_data[..., :4].copy()
     maps_i_correct[np.logical_not(mask_data), :] = 0
     assert_almost_equal(maps_i_correct, maps_i)
