@@ -8,7 +8,7 @@ from nilearn._utils.niimg import repr_niimgs
 from nilearn.typing import NiimgLike
 
 
-def dataframe_to_html(df, precision, **kwargs):
+def dataframe_to_html(df: pd.DataFrame, precision: int, **kwargs) -> str:
     """Make HTML table from provided dataframe.
 
     Removes HTML5 non-compliant attributes (ex: `border`).
@@ -40,6 +40,8 @@ def dataframe_to_html(df, precision, **kwargs):
 def model_attributes_to_dataframe(model):
     """Return dataframe with pertinent model attributes & information.
 
+    TODO (sklearn > 1.6.2) remove
+
     Parameters
     ----------
     model : Any masker object.
