@@ -141,6 +141,7 @@ def data_butterworth_multiple_timeseries(
     return data
 
 
+@pytest.mark.thread_unsafe
 def test_butterworth(data_butterworth_single_timeseries):
     """Check butterworth onsingle timeseries."""
     sampling = 100
@@ -166,6 +167,7 @@ def test_butterworth(data_butterworth_single_timeseries):
     assert id(out_single) != id(data)
 
 
+@pytest.mark.thread_unsafe
 def test_butterworth_multiple_timeseries(
     data_butterworth_single_timeseries, data_butterworth_multiple_timeseries
 ):
@@ -338,6 +340,7 @@ def test_standardize_error(rng):
         standardize_signal(a, standardize="zscore")
 
 
+@pytest.mark.thread_unsafe
 def test_standardize(rng):
     """Test starndardize_signal with several options."""
     n_features = 10
@@ -777,6 +780,7 @@ def test_clean_errros(signals):
         clean(signals, high_pass=False)
 
 
+@pytest.mark.thread_unsafe
 def test_clean_confounds():
     """Check output of cleaning when counfoun is passed."""
     signals, noises, confounds = generate_signals(
@@ -872,6 +876,7 @@ def test_clean_confounds_detrending():
     assert (abs(coeffs) < 1000.0 * EPS).all()  # trend removed
 
 
+@pytest.mark.thread_unsafe
 def test_clean_standardize_true_false():
     """Check difference between standardize False and True."""
     signals, _, _ = generate_signals(n_features=41, n_confounds=5, length=45)
@@ -1737,8 +1742,9 @@ full_path_design_matrix_file = my_path / "spm_dmtx.npz"
 DESIGN_MATRIX = np.load(full_path_design_matrix_file)
 
 
+@pytest.mark.thread_unsafe
 def test_cosine_drift():
-    """Check cosine drift created buy nilearn."""
+    """Check cosine drift created by nilearn."""
     spm_drifts = DESIGN_MATRIX["cosbf_dt_1_nt_20_hcut_0p1"]
     frame_times = np.arange(20)
     high_pass_frequency = 0.1
